@@ -1,7 +1,6 @@
-/*-
- * chasen.c - ChaSen main program
- *
- * Copyright (C) 1996, 1997, 2000 Nara Institute of Science and Technology
+/*
+ * Copyright (C) 1996, 1997, 2000, 2001,
+ *                             Nara Institute of Science and Technology
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,13 +33,14 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Author: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Apr. 1997
+ * $Id: chasen.c,v 1.7 2001/02/23 12:51:34 kazuma-t Exp $
  *
- * $Id: chasen.c,v 1.3.4.1 2000/12/18 20:08:20 masayu-a Exp $
  */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #include "chalib.h"
 #include "pat.h"
@@ -57,19 +57,13 @@ static char *output_file = NULL;
 static char chasen_host[MAXHOSTNAMELEN];
 static unsigned short chasen_port = CHASEN_PORT;
 
-#ifdef KOCHA
-#define CHA_NAME       "KoCha"
-#define CHA_PROG       "kocha"
-#else
 #define CHA_NAME       "ChaSen"
 #define CHA_PROG       "chasen"
-#endif
 
 /*
  * opt_form_usage()
  */
-static void opt_form_usage(fp)
-    FILE *fp;
+static void opt_form_usage(FILE *fp)
 {
     static char *message[] = {
 	"Conversion characters of -F option:\n",
@@ -84,7 +78,8 @@ static void opt_form_usage(fp)
 	"  %a0     pronounciation (inflected form)\n",
 	"  %A0     pronounciation (base form)\n",
 	"  %rABC   surface form with ruby (the format is \"AkanjiBkanaC\")\n",
-	"  %i      semantic information\n",
+	"  %i,%i1  first candidate of semantic information\n",
+	"  %i0     semantic information\n",
 	"  %Ic     semantic information (if NIL, print character 'c'.)\n",
 	"  %Pc     part of speech separated by character 'c'\n",
 	"  %Pnc    part of speech separated by character 'c'\n",
@@ -137,7 +132,7 @@ static void opt_form_usage(fp)
 	"\n",
 	"Examples:\n",
 	"  \"%m \"         split words by space (wakachi-gaki)\n",
-	"  \"%y\"          Kana to Kanji conversion\n",
+	"  \"%y\"          Kanji to Kana conversion\n",
 	"  \"%r ()\"       print surface form with ruby as \"kanji(kana)\"\n",
 	"  \"%m\\t%y\\t%M\\t%U(%P-)\\t%T \\t%F \\n\"           same as -f option (default)\n",
 	"  \"%m\\t%U(%y)\\t%M\\t%P- %h %T* %t %F* %f\\n\"    same as -e option\n",
@@ -157,8 +152,7 @@ static void opt_form_usage(fp)
 /*
  *  usage()
  */
-static void usage(fp)
-    FILE *fp;
+static void usage(FILE *fp)
 {
     static char *message[] = {
 	"Usage: ", CHA_PROG, " [options] [file...]\n",
@@ -211,8 +205,7 @@ static void usage(fp)
 /*
  * set_chasen_port()
  */
-static void set_chasen_port(port)
-    char *port;
+static void set_chasen_port(char *port)
 {
     if ((chasen_port = atoi(port)) <= 0)
       cha_exit(1, "Illegal port No: %s", port);
@@ -221,8 +214,7 @@ static void set_chasen_port(port)
 /*
  * set_chasen_server()
  */
-static void set_chasen_server(server)
-    char *server;
+static void set_chasen_server(char *server)
 {
     char *colon;
     int len;
@@ -244,8 +236,7 @@ static void set_chasen_server(server)
 /*
  * getopt_argv()
  */
-static void getopt_argv(argv)
-    char **argv;
+static void getopt_argv(char **argv)
 {
     int c;
 
@@ -299,12 +290,11 @@ static void getopt_argv(argv)
 /*
  * do_chasen_standalone()
  */
-static void do_chasen_standalone(ifp, ofp)
-    FILE *ifp, *ofp;
+static void do_chasen_standalone(FILE *ifp, FILE *ofp)
 {
     int istty;
 
-    /* ϤɸϤɤ */
+    /* output: whether `stdout' or not  */
     istty = ofp == stdout && isatty(fileno(stdout));
 
     while (!chasen_fparse(ifp, ofp))
@@ -317,9 +307,7 @@ static void do_chasen_standalone(ifp, ofp)
  *
  * return: exit code
  */
-static int chasen_standalone(argv, output)
-    char **argv;
-    FILE *output;
+static int chasen_standalone(char **argv, FILE *output)
 {
     /* standalone */
     if (chasen_getopt_argv(argv, stderr))
@@ -338,13 +326,12 @@ static int chasen_standalone(argv, output)
 /*
  * main()
  */
-int main(argc, argv)
-    int argc;
-    char **argv;
+int main(int argc, char *argv[])
 {
     char *serv_env;
-    extern char *getenv();
-    extern int chasen_client(), chasen_server();
+    extern char *getenv(const char*);
+    extern int chasen_client(char**, FILE*, char*, int);
+    extern int chasen_server(char**, int);
 
     cha_set_progpath(argv[0]);
 
@@ -375,8 +362,7 @@ int main(argc, argv)
 #endif
 	  rc = chasen_standalone(argv, output);
 	if (output != stdout)
-	  close(output);
+	  fclose(output);
 	return rc;
     }
 }
-
