@@ -1,43 +1,11 @@
-/*-
- * chadic.h
- *
- * Copyright (c) 2000 Nara Institute of Science and Technology
- * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in the
- *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by Nara Institute of 
- *      Science and Technology.
- * 4. The name Nara Institute of Science and Technology may not be used to
- *    endorse or promote products derived from this software without specific
- *    prior written permission.
- *    
- *
- * THIS SOFTWARE IS PROVIDED BY Nara Institute of Science and Technology 
- * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A 
- * PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE Nara Institute
- * of Science and Technology BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
- * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
- * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
- * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
- * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * 1990/12/06/Thu  Yutaka MYOKI(Nagao Lab., KUEE)
- * 1994/02 changed by T.Nakamura 
- *
- * $Id: chadic.h,v 1.10.4.1 2000/12/18 20:08:30 masayu-a Exp $
- */
+/*
+==============================================================================
+        chadic.h
+                1990/12/06/Thu  Yutaka MYOKI(Nagao Lab., KUEE)
+                1990/01/09/Wed  Last Modified
+                                          >>> 94/02 changed by T.Nakamura <<<
+==============================================================================
+*/
 #ifndef __CHADIC_H__
 #define __CHADIC_H__
 
@@ -247,26 +215,29 @@ typedef struct _cell {
     } value;
 } chasen_cell_t;
 
-/* changed by T.Nakamura and S.Kurohashi 
-   ¤ mrph_t ٤Ƥξ 
-   ¤ MORPHEME Ϥʤʤä */
+/* this structure is used only in mkchadic */
+               /* changed by T.Nakamura and S.Kurohashi 
+                  ¤ mrph_t ٤Ƥξ 
+                  ¤ MORPHEME Ϥʤʤä */
+/* morpheme */
 typedef struct _mrph {
-    char midasi[MIDASI_LEN];
-    char yomi[MIDASI_LEN];
-    char *info;
-    char *base;
-    char pron[MIDASI_LEN];
-    unsigned short hinsi;
-    unsigned char ktype;
-    unsigned char kform;
+    char midasi[MIDASI_LEN];  /* surface form */
+    char yomi[MIDASI_LEN];    /* Japanese reading */
+    char *info;               /* semantic information */
+    char *base;               /* base form */
+    char pron[MIDASI_LEN];    /* Japanese pronunciation */
+    unsigned short hinsi;     /* POS number */
+    unsigned char ktype;      /* Conjugation type number */
+    unsigned char kform;      /* Conjugation form number */
 
-    short con_tbl;
-    short length;
-    unsigned short weight;
+    short con_tbl;            /* connection table number */
+    short length;             /* the length of surface form */
+    unsigned short weight;    /* cost for morpheme  */
 
-    char is_undef;
+    char is_undef;            /* the unseen word or not */
 } mrph_t;
 
+/* POS information */
 typedef struct _hinsi_t {
     short *path;
     short *daughter;
@@ -278,13 +249,13 @@ typedef struct _hinsi_t {
     unsigned char cost;
 } hinsi_t;
 
-/* ѷ */
+/* ѷ conjugation type */
 typedef struct _ktype {
     char   *name;
     short  basic;
 } ktype_t;
 
-/* ѷ */
+/* ѷ conjugation form */
 typedef struct _kform {
     char  *name;
     char  *gobi;
@@ -293,7 +264,7 @@ typedef struct _kform {
     char  *pgobi;
 } kform_t;
 
-/* Ϣɽ */
+/* Ϣɽ connection matrix */
 typedef struct _rensetu_pair {
     short  index;
     short  i_pos;
@@ -345,7 +316,8 @@ FILE *cha_fopen2(char*, char*, char*, int);
 FILE *cha_fopen_grammar(char*, char*, int, int, char**);
 FILE *cha_fopen_grammar2(char*, char*, char*, int, int, char**);
 void *cha_malloc(size_t);
-#define cha_free(ptr) free(ptr)
+void *cha_realloc(void*, size_t);
+#define cha_free(ptr) (free(ptr))
 char *cha_strdup(char*);
 
 void cha_exit(int, char*, ...);
