@@ -1,7 +1,6 @@
-/*-
- * chalib.c
- *
- * Copyright (c) 1996,1997 Nara Institute of Science and Technology
+/*
+ * Copyright (C) 1996, 2000, 2001,
+ *                             Nara Institute of Science and Technology
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,9 +32,8 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * Author: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Sep. 1996
- *
- * $Id: chalib.c,v 1.9.4.1 2000/12/18 20:08:30 masayu-a Exp $
+ * modified by A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Sep. 1996
+ * $Id: chalib.c,v 1.14 2001/02/23 11:50:10 kazuma-t Exp $
  */
 
 #include "chalib.h"
@@ -50,6 +48,7 @@
 
 int Cha_cost_width = -1;
 int Cha_lang_j = 0, Cha_lang_e = 0;
+int Cha_encode = CHA_ENCODE_EUC;
 
 static int cost_width0;
 
@@ -64,13 +63,12 @@ static char *opt_form_string;
 /*
  *  cha_version()
  */
-void cha_version(fp)
-    FILE *fp;
+void cha_version(FILE *fp)
 {
     if (!fp)
       return;
 
-    fprintf(fp, "%s version %s (c) 1996-2000 Nara Institute of Science and Technology\n",
+    fprintf(fp, "%s version %s (c) 1996-2001 Nara Institute of Science and Technology\n",
 	    CHA_NAME, VERSION);
     fprintf(fp, "Grammar files are in ChaSen's new v-gram format.\n");
 }
@@ -78,8 +76,7 @@ void cha_version(fp)
 /*
  * cha_set_opt_form()
  */
-void cha_set_opt_form(format)
-    char *format;
+void cha_set_opt_form(char *format)
 {
     char *f;
 
@@ -132,8 +129,7 @@ void cha_set_opt_form(format)
 /*
  * cha_set_language()
  */
-void cha_set_language(langstr)
-    char *langstr;
+void cha_set_language(char *langstr)
 {
     char *s;
 
@@ -149,8 +145,7 @@ void cha_set_language(langstr)
 /*
  * cha_set_cost_width()
  */
-void cha_set_cost_width(cw)
-    int cw;
+void cha_set_cost_width(int cw)
 {
     cost_width0 = cw * MRPH_DEFAULT_WEIGHT;
 
@@ -165,9 +160,7 @@ void cha_set_cost_width(cw)
  *   0 - ok
  *   1 - error
  */
-int chasen_getopt_argv(argv, fp)
-    char **argv;
-    FILE *fp;
+int chasen_getopt_argv(char **argv, FILE *fp)
 {
     int c;
 
@@ -252,7 +245,7 @@ int chasen_getopt_argv(argv, fp)
 /***********************************************************************
  * command_usage()
  ***********************************************************************/
-static void command_usage()
+static void command_usage(void)
 {
     static char *message[] = {
 	"commands are:\n",
@@ -278,8 +271,7 @@ static void command_usage()
 /*
  * chomp a string
  */
-static void chomp(str)
-    char *str;
+static void chomp(char *str)
 {
     int len;
 
@@ -298,14 +290,13 @@ static void chomp(str)
  *     0 - succeed
  *     1 - quit chasen
  ***********************************************************************/
-static int chasen_command(comm)
-    char *comm;
+static int chasen_command(char *comm)
 {
     char *arg;
     int i;
     char *rslt[256]; /* ѿ for ñå(exact match) */
     FILE *of; /* intե˽񤭹(ɲ)Τ */
-    long new_word_index;
+    long new_word_index = 0;
     char tmpstr[2000];
 
     arg = comm + 2;
@@ -365,8 +356,7 @@ static int chasen_command(comm)
 	fclose(of);
 	/* ޥåפľƤ餦ν */
 	pat_text_reopen(Pat_dicfile[obj_dic_no], tmpstr);
-	pat_insert(Pat_dicfile[obj_dic_no],
-		   arg, new_word_index, "\t");
+	pat_insert(Pat_dicfile[obj_dic_no], arg, new_word_index);
 	break;
       case 's':
 	/* ڤΥ */
@@ -415,9 +405,7 @@ static int chasen_command(comm)
  *     0 - ok / no result / too many morphs
  *     1 - quit
  */
-static int chasen_sparse_main(input, output)
-    char *input;
-    FILE *output;
+static int chasen_sparse_main(char *input, FILE *output)
 {
     char *crlf;
 
@@ -485,8 +473,7 @@ static int chasen_sparse_main(input, output)
 /*
  * file -> file
  */
-int chasen_fparse(fp_in, fp_out)
-    FILE *fp_in, *fp_out;
+int chasen_fparse(FILE *fp_in, FILE *fp_out)
 {
     char line[CHA_INPUT_SIZE];
 
@@ -498,9 +485,7 @@ int chasen_fparse(fp_in, fp_out)
 /*
  * string -> file
  */
-int chasen_sparse(str_in, fp_out)
-    char *str_in;
-    FILE *fp_out;
+int chasen_sparse(char *str_in, FILE *fp_out)
 {
     int rc;
     char *euc_str;
@@ -524,8 +509,7 @@ int chasen_sparse(str_in, fp_out)
 /*
  * file -> string
  */
-char *chasen_fparse_tostr(fp_in)
-    FILE *fp_in;
+char *chasen_fparse_tostr(FILE *fp_in)
 {
     char line[CHA_INPUT_SIZE];
 
@@ -541,8 +525,7 @@ char *chasen_fparse_tostr(fp_in)
 /*
  * string -> string
  */
-char *chasen_sparse_tostr(str_in)
-    char *str_in;
+char *chasen_sparse_tostr(char *str_in)
 {
     char *euc_str;
 
@@ -557,10 +540,7 @@ char *chasen_sparse_tostr(str_in)
     return cha_get_output();
 }
 
-char *cha_fgets(s, n, fp)
-    char *s;
-    int n;
-    FILE *fp;
+char *cha_fgets(char *s, int n, FILE *fp)
 {
     if (opt_ja)
       return cha_jfgets(s, n, fp);
@@ -568,8 +548,7 @@ char *cha_fgets(s, n, fp)
       return cha_fget_line(s, n, fp);
 }
 
-static void set_dic_filename(filename, s)
-    char *filename, *s;
+static void set_dic_filename(char *filename, char *s)
 {
 #ifdef PATHTYPE_MSDOS
     if (*s == PATH_DELIMITER || *s && s[1] == ':')
@@ -585,8 +564,7 @@ static void set_dic_filename(filename, s)
 /*
  * cha_read_patdic - read patricia dictionaries
  */
-void cha_read_patdic(cell)
-    chasen_cell_t *cell;
+void cha_read_patdic(chasen_cell_t *cell)
 {
     int  num;
     char patname[CHA_FILENAME_LEN];
@@ -599,9 +577,9 @@ void cha_read_patdic(cell)
     for (num = 0; !nullp(cell); num++, cell = cha_cdr(cell)) {
 	if (num >= PAT_DIC_NUM)
 	  cha_exit_file(1, "too many patricia dictionary files");
-	set_dic_filename(&patdic_filename[num], cha_s_atom(cha_car(cell)));
+	set_dic_filename(patdic_filename[num], cha_s_atom(cha_car(cell)));
 
-	/* Υץ */
+	/* open patdic */
 	sprintf(textname, "%s.int", patdic_filename[num]);
 	sprintf(patname, "%s.pat", patdic_filename[num]);
 	Pat_dicfile[num] = pat_open(textname, patname);
@@ -612,8 +590,7 @@ void cha_read_patdic(cell)
 /*
  * cha_read_sufdic - read SUFARY dictionaries
  */
-void cha_read_sufdic(cell)
-    chasen_cell_t *cell;
+void cha_read_sufdic(chasen_cell_t *cell)
 {
     int  num;
     char filename[CHA_FILENAME_LEN];
@@ -626,9 +603,9 @@ void cha_read_sufdic(cell)
     for (num = 0; !nullp(cell); num++, cell = cha_cdr(cell)) {
 	if (num >= PAT_DIC_NUM)
 	  cha_exit_file(1, "too many SUFARY dictionary files");
-	set_dic_filename(&sufdic_filename[num], cha_s_atom(cha_car(cell)));
+	set_dic_filename(sufdic_filename[num], cha_s_atom(cha_car(cell)));
 
-	/* Υץ */
+	/* open sufdic */
 	sprintf(filename, "%s.int", sufdic_filename[num]);
 	sprintf(ary_filename, "%s.ary", sufdic_filename[num]);
 	Suf_dicfile[num] = sa_openfiles(filename, ary_filename);
