@@ -1,7 +1,9 @@
-/*-
- * connect.c
+/*
  *
- * Copyright (c) 2000 Nara Institute of Science and Technology
+ *  connect.c - library for connection matrix
+ *
+ * Copyright (C) 2000, 2001,  Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,12 +33,10 @@
  * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
  * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * 1990/12/17/Mon	Yutaka MYOKI(Nagao Lab., KUEE)
- *
- * $Id: connect.c,v 1.3.4.1 2000/12/18 20:08:31 masayu-a Exp $
- */
+ * $Id: connect.c,v 1.6 2001/02/23 12:51:34 kazuma-t Exp $
+*/
 
 #include "chadic.h"
 
@@ -54,40 +54,37 @@ static connect_rule_t *connect_mtr;
         rensetu table
 ------------------------------------------------------------------------------
 */
-static int cmp_pair(pair1, pair2)
-    rensetu_pair_t *pair1, *pair2;
+static int cmp_pair(rensetu_pair_t *pair1, rensetu_pair_t *pair2)
 {
     int ret;
     
-    /* Ф */
+    /* Ф */  /* surface form */
     if (pair1->goi == NULL && pair2->goi != NULL)
       return 1;
     if (pair1->goi != NULL && pair2->goi == NULL)
       return -1;
     
-    /* ʻʬ */
+    /* ʻʬ */  /* POS */
     if ((ret = pair1->hinsi - pair2->hinsi) != 0)
       return ret;
 
-    /* ѷ*/
+    /* ѷ*/  /* Conjugation type */
     if ((ret = pair1->type - pair2->type) != 0)
       return ret;
     
-    /* Ф */
+    /* Ф */ /* surface form */
     if (pair1->goi != NULL && pair2->goi != NULL)
       if ((ret = strcmp(pair1->goi, pair2->goi)) != 0)
 	return ret;
     
-    /* ѷ */
+    /* ѷ */ /* Conjugation form */
     if ((ret = pair1->form - pair2->form) != 0)
       return ret;
     
     return pair1->index - pair2->index;
 }
 
-static char *cha_numtok(s, valp)
-    char *s;
-    int *valp;
+static char *cha_numtok(char *s, int *valp)
 {
     int minus = 0;
 
@@ -109,9 +106,7 @@ static char *cha_numtok(s, valp)
     return s;
 }
 
-void cha_read_table(fp_out, dir)
-    FILE *fp_out;
-    int dir;
+void cha_read_table(FILE *fp_out, int dir)
 {
     FILE *fp;
     char *filepath;
@@ -176,9 +171,7 @@ void cha_read_table(fp_out, dir)
 }
 
 /* for EDRdic '94.Mar */
-void cha_check_edrtable(mrph_p, x)
-    mrph_t *mrph_p;
-    chasen_cell_t *x;
+void cha_check_edrtable(mrph_t *mrph_p, chasen_cell_t *x)
 {
     int i;
 
@@ -193,9 +186,7 @@ void cha_check_edrtable(mrph_p, x)
 }
 
 /* for EDRdic '94.Mar */
-void cha_check_edrtable_str(mrph_p, str)
-    mrph_t *mrph_p;
-    char *str;
+void cha_check_edrtable_str(mrph_t *mrph_p, char *str)
 {
     int i;
   
@@ -209,20 +200,18 @@ void cha_check_edrtable_str(mrph_p, str)
     cha_exit_file(1, "no morpheme in EDR table");
 }
 
-static int find_table(mrph, pair)
-    mrph_t *mrph;
-    rensetu_pair_t *pair;
+static int find_table(mrph_t *mrph, rensetu_pair_t *pair)
 {
     int ret;
 
-    /* ʻʬ */
+    /* ʻʬ */ /* POS */
     if ((ret = mrph->hinsi - pair->hinsi) != 0)
       return ret;
-    /* ѷ */
+    /* ѷ */ /* Conjugation type */
     if ((ret = mrph->ktype - pair->type) != 0)
       return ret;
 
-    /* Ф */
+    /* Ф */ /* surface form */
     if (pair->goi && (ret = strcmp(mrph->midasi,pair->goi)))
       return ret;
 
@@ -232,8 +221,7 @@ static int find_table(mrph, pair)
     return 0;
 }
 
-int cha_check_table(mrph) /* 970301 tatuo: void -> int for  */
-    mrph_t *mrph;
+int cha_check_table(mrph_t *mrph) /* 970301 tatuo: void -> int for  */
 {
     rensetu_pair_t *ret;
 
@@ -260,8 +248,7 @@ int cha_check_table(mrph) /* 970301 tatuo: void -> int for  */
     return 0; /* 970301 tatuo: ꤢ 0 ֤ */
 }
 
-int cha_check_table_for_undef(hinsi)
-    int hinsi;
+int cha_check_table_for_undef(int hinsi)
 {
      int i;
 
@@ -278,8 +265,7 @@ int cha_check_table_for_undef(hinsi)
         rensetu matrix
 ------------------------------------------------------------------------------
 */
-void cha_read_matrix(fp_out)
-    FILE *fp_out;
+void cha_read_matrix(FILE *fp_out)
 {
     FILE *fp;
     char *filepath;
@@ -326,41 +312,7 @@ void cha_read_matrix(fp_out)
     fclose(fp);
 }
 
-#ifdef KOCHA
-int cha_check_automaton(state, state_prev, midasi, is_undef, con, undef_con_cost, costp)
-    int state, state_prev;
-    char *midasi;
-    int is_undef, con, undef_con_cost, *costp;
-{
-    int cost, cost_prev;
-
-    cost = connect_mtr[state * j_num + rensetu_tbl[con].j_pos].cost;
-    /* 2: ľñȤ³ */
-    if (cost == 0)
-      cost = undef_con_cost;
-    else if (!is_undef &&
-	     (unsigned char)midasi[0] == 0xA1 &&
-	     (unsigned char)midasi[1] == 0xA1) {
-	/* 2: 2ñȤ³ */
-	cost_prev =
-	  (int)connect_mtr[state_prev * j_num + rensetu_tbl[con].j_pos].cost / 100;
-
-#ifdef KOCHA_DEBUG
-	printf("[c1:%d,c2:%d,cost:%d]\n",state_prev,rensetu_tbl[con].j_pos,cost_prev);
-#endif
-	if (cost_prev == 0)
-	  cost = undef_con_cost;
-	else
-	  cost += cost_prev;
-    }
-
-    *costp = cost;
-
-    return rensetu_tbl[con].i_pos;
-}
-#else /* !KOCHA */
-int cha_check_automaton(state, con, undef_con_cost, costp)
-    int state, con, undef_con_cost, *costp;
+int cha_check_automaton(int state, int con, int undef_con_cost, int *costp)
 {
     connect_rule_t *cr;
 #if 0
@@ -379,5 +331,3 @@ int cha_check_automaton(state, con, undef_con_cost, costp)
 
     return rensetu_tbl[cr->next + con].i_pos;
 }
-#endif /* !KOCHA */
-
