@@ -1,7 +1,9 @@
-/*-
+/*
  * getopt.c - ChaSen version of getopt()
  *
- * Copyright (c) 1996, 1997, 2000 Nara Institute of Science and Technology
+ * Copyright (C) 1996, 1997, 2000, 2001, 
+ *                            Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,11 +33,9 @@
  * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
  * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Author: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Apr 1997
- *
- * $Id: getopt.c,v 1.1.1.1.6.1 2000/12/18 20:08:31 masayu-a Exp $
+ * $Id: getopt.c,v 1.3 2001/02/23 11:50:10 kazuma-t Exp $
  */
 
 #include <stdio.h>
@@ -44,10 +44,7 @@
 int Cha_optind = 0;
 char *Cha_optarg;
 
-int cha_getopt(argv, optstring, fp)
-    char **argv;
-    char *optstring;
-    FILE *fp;
+int cha_getopt(char **argv, char *optstring, FILE *fp)
 {
     static char *nextchar;
     char *op, c;
@@ -103,18 +100,15 @@ int cha_getopt(argv, optstring, fp)
 /*
  * chasen_getopt
  */
-int cha_getopt_chasen(argv, fp)
-    char **argv;
-    FILE *fp;
+int cha_getopt_chasen(char **argv, FILE *fp)
 {
     return cha_getopt(argv, "sP:D:RabmpdvfecMo:F:L:l:jr:w:O:BChV", fp);
 }
 
-#ifdef TEST
 
-int main (argc, argv)
-    int argc;
-    char **argv;
+
+#ifdef TEST
+int main (int argc, char *argv[])
 {
     int c;
 
@@ -155,5 +149,4 @@ int main (argc, argv)
 
     exit (0);
 }
-
 #endif /* TEST */
