@@ -1,7 +1,9 @@
-/*-
- * iotool.c
+/*
+ * iotools.c 
  *
- * Copyright (c) 1996, 1997, 2000 Nara Institute of Science and Technology
+ * Copyright (C) 1996, 1997, 2000, 2001, 
+ *                            Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,22 +33,16 @@
  * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
  * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * 1990/12/14/Fri	Yutaka MYOKI(Nagao Lab., KUEE)
- * 1990/12/25/Tue	Last Modified
+ * 1990/12/25/Tue	Modified
  * Oct. 1996       A.Kitauchi <akira-k@is.aist-nara.ac.jp>
- *
- * $Id: iotool.c,v 1.6.4.1 2000/12/18 20:08:31 masayu-a Exp $
+ * $Id: iotool.c,v 1.10 2001/02/23 12:51:34 kazuma-t Exp $
  */
-
 #include <stdarg.h>
 #include <stdio.h>
 #include "chadic.h"
 
-#ifdef KOCHA
-#define RCFILE "/.kocharc"
-#else
 #ifdef PATHTYPE_MSDOS
 #define RCFILE "\\chasenrc"
 #define RC2FILE "\\chasen2rc"
@@ -54,7 +50,7 @@
 #define RCFILE "/.chasenrc"
 #define RC2FILE "/.chasen2rc"
 #endif
-#endif
+
 #define OLDRCFILE "/.jumanrc"
 
 int Cha_lineno, Cha_lineno_error;
@@ -69,9 +65,7 @@ static char chasenrc_path[CHA_FILENAME_LEN];
 /***********************************************************************
  * cha_convert_escape - convert escape characters
  ***********************************************************************/
-char *cha_convert_escape(str, ctrl_only)
-    char *str;
-    int ctrl_only;
+char *cha_convert_escape(char *str, int ctrl_only)
 {
     char *s1, *s2;
 
@@ -103,9 +97,7 @@ char *cha_convert_escape(str, ctrl_only)
  *	progpath is used in cha_exit() and cha_exit_file()
  ***********************************************************************/
 #if defined _WIN32 && ! defined __CYGWIN__
-static void which(filename, path)
-    char *filename;
-    char *path;
+static void which(char *filename, char *path)
 {
     char *ps, *pe;
     int fl;
@@ -134,8 +126,7 @@ static void which(filename, path)
 }
 #endif /* _WIN32 */
 
-void cha_set_progpath(path)
-    char *path;
+void cha_set_progpath(char *path)
 {
 #if defined _WIN32 && ! defined __CYGWIN__
     if (strchr(path, PATH_DELIMITER) != NULL)
@@ -152,8 +143,7 @@ void cha_set_progpath(path)
  *
  *	this function is called when -r option is used.
  ***********************************************************************/
-void cha_set_rcpath(filename)
-    char *filename;
+void cha_set_rcpath(char *filename)
 {
     strcpy(chasenrc_path, filename);
 }    
@@ -163,7 +153,7 @@ void cha_set_rcpath(filename)
  *
  *	called only from chasen.c
  ***********************************************************************/
-char *cha_get_rcpath()
+char *cha_get_rcpath(void)
 {
     return chasenrc_path;
 }
@@ -173,13 +163,12 @@ char *cha_get_rcpath()
  *
  *	called only from chasen.c
  ***********************************************************************/
-char *cha_get_grammar_dir()
+char *cha_get_grammar_dir(void)
 {
     return grammar_dir;
 }
 
-void cha_set_filepath(filename)
-    char *filename;
+void cha_set_filepath(char *filename)
 {
     strcpy(filepath, filename);
     Cha_lineno = Cha_lineno_error = 0;
@@ -191,9 +180,7 @@ void cha_set_filepath(filename)
  * inputs:
  *	ret - exit code (don't exit if ret < 0)
  ***********************************************************************/
-FILE *cha_fopen(filename, mode, ret)
-    char *filename, *mode;
-    int ret;
+FILE *cha_fopen(char *filename, char *mode, int ret)
 {
     FILE *fp;
 
@@ -213,9 +200,7 @@ FILE *cha_fopen(filename, mode, ret)
     return fp;
 }
 
-FILE *cha_fopen2(filename1, filename2, mode, ret)
-    char *filename1, *filename2, *mode;
-    int ret;
+FILE *cha_fopen2(char *filename1, char *filename2, char *mode, int ret)
 {
     FILE *fp;
 
@@ -244,9 +229,7 @@ FILE *cha_fopen2(filename1, filename2, mode, ret)
  * outputs:
  *	filepathp - file path string
  ***********************************************************************/
-FILE *cha_fopen_grammar(filename, mode, ret, dir, filepathp)
-    char *filename, *mode, **filepathp;
-    int ret, dir;
+FILE *cha_fopen_grammar(char *filename, char *mode, int ret, int dir, char **filepathp)
 {
     FILE *fp;
 
@@ -271,9 +254,7 @@ FILE *cha_fopen_grammar(filename, mode, ret, dir, filepathp)
     }
 }
 
-FILE *cha_fopen_grammar2(filename1, filename2, mode, ret, dir, filepathp)
-    char *filename1, *filename2, *mode, **filepathp;
-    int ret, dir;
+FILE *cha_fopen_grammar2(char *filename1, char *filename2, char *mode, int ret, int dir, char **filepathp)
 {
     FILE *fp;
 
@@ -302,8 +283,7 @@ FILE *cha_fopen_grammar2(filename1, filename2, mode, ret, dir, filepathp)
 /*
  * cha_malloc()
  */
-void *cha_malloc(n)
-    size_t n;
+void *cha_malloc(size_t n)
 {
     void *p;
 
@@ -313,9 +293,18 @@ void *cha_malloc(n)
     return p;
 }
 
+void *cha_realloc(void *ptr, size_t n)
+{
+    void *p;
+
+    if ((p = realloc(ptr, n)) == NULL)
+      cha_exit_perror("realloc");
+
+    return p;
+}
+
 #define CHA_MALLOC_SIZE (1024 * 64)
-static char *cha_malloc_char(size)
-    int size;
+static char *cha_malloc_char(int size)
 {
     static int idx = CHA_MALLOC_SIZE;
     static char *ptr;
@@ -329,8 +318,7 @@ static char *cha_malloc_char(size)
     return ptr + idx - size;
 }
 
-char *cha_strdup(str)
-    char *str;
+char *cha_strdup(char *str)
 {
     char *newstr;
 
@@ -343,8 +331,7 @@ char *cha_strdup(str)
 /*
  * cha_exit() - print error messages on stderr and exit
  */
-void cha_set_stderr(fp)
-    FILE *fp;
+void cha_set_stderr(FILE *fp)
 {
     cha_stderr = fp;
 }
@@ -408,21 +395,19 @@ void cha_exit_file(int status, char *format, ...)
     }
 }
 
-void cha_perror(s)
-    char *s;
+void cha_perror(char *s)
 {
     cha_exit(-1, "");
     perror(s);
 }
 
-void cha_exit_perror(s)
-    char *s;
+void cha_exit_perror(char *s)
 {
     cha_perror(s);
     exit(1);
 }
 
-FILE *cha_fopen_rcfile()
+FILE *cha_fopen_rcfile(void)
 {
     FILE *fp;
     char *home_dir, *rc_env, *getenv();
@@ -496,7 +481,7 @@ FILE *cha_fopen_rcfile()
 /*
  * read .chasenrc and set grammar directory
  */
-void cha_read_grammar_dir()
+void cha_read_grammar_dir(void)
 {
     FILE *fp;
     chasen_cell_t *cell;
@@ -529,4 +514,3 @@ void cha_read_grammar_dir()
 
     fclose(fp);
 }
-
