@@ -1,7 +1,9 @@
-/*-
- * katuyou.c
+/*
+ * katuyou.c - conjugation
  *
- * Copyright (c) 1996, 1997, 2000 Nara Institute of Science and Technology
+ * Copyright (C) 2000, 2001, 
+ *                            Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,11 +33,9 @@
  * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
  * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * 1990/12/17/Mon	Yutaka MYOKI(Nagao Lab., KUEE)
- *
- * $Id: katuyou.c,v 1.3.4.1 2000/12/18 20:08:31 masayu-a Exp $
+ * $Id: katuyou.c,v 1.6 2001/02/23 12:51:34 kazuma-t Exp $
  */
 
 #include "chadic.h"
@@ -43,15 +43,10 @@
 ktype_t Cha_type[TYPE_NUM];
 kform_t Cha_form[TYPE_NUM][FORM_NUM];
 
-#ifdef KOCHA2
-char *gomatsu[] = {"첻", "Ҳ", "", NULL};
-#endif
-
 /***********************************************************************
  * read_type_form
  ***********************************************************************/
-static void read_type_form(fp)
-    FILE *fp;
+static void read_type_form(FILE *fp)
 {
     chasen_cell_t *cell1, *cell2;
     int i, j;
@@ -103,15 +98,7 @@ static void read_type_form(fp)
 	}
 	if (!Cha_type[i].basic)
 	  cha_exit_file(1, "no basic form");
-#ifdef KOCHA_DEBUG
-	printf("[type: %d,%s]\n", i, Cha_type[i].name);
-#endif
     }
-#ifdef KOCHA2
-    for (j = 0; gomatsu[j]; i++, j++) {
-	Cha_type[i].name = cha_strdup(gomatsu[j]);
-    }
-#endif
 }
 
 /***********************************************************************
@@ -122,9 +109,7 @@ static void read_type_form(fp)
  *	      1: read from grammar directory
  *	      2: read from current directory or grammar directory
  ***********************************************************************/
-void cha_read_katuyou(fp_out, dir)
-    FILE *fp_out;
-    int dir;
+void cha_read_katuyou(FILE *fp_out, int dir)
 {
     FILE *fp;
     char *filepath;
