@@ -1,7 +1,9 @@
-/*-
+/*
  * lisp.c - utility functions like LISP
  *
- * Copyright (c) 1996, 1997, 2000 Nara Institute of Science and Technology
+ * Copyright (C) 1996, 1997, 2000, 2001, 
+ *                            Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -31,15 +33,14 @@
  * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF 
  * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
- * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Author: 1990/11/12/Mon Yutaka MYOKI(Nagao Lab., KUEE)
- *         special thanks to Itsuki NODA
+ *         1990/12/16/Mon Modified special thanks to Itsuki NODA
  *         A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Apr. 1997
- *
- * $Id: lisp.c,v 1.3.4.1 2000/12/18 20:08:31 masayu-a Exp $
+ * $Id: lisp.c,v 1.5 2001/02/23 11:50:10 kazuma-t Exp $
  */
 
+
 #include "chadic.h"
 
 #define COMMENTCHAR	';'
@@ -59,8 +60,7 @@ static int is_bol = 1;
 static int c_stacked = EOF;
 static int c_skip = 0;
 
-static int cha_getc_server(fp)
-    FILE *fp;
+static int cha_getc_server(FILE *fp)
 {
     int c;
 
@@ -91,23 +91,22 @@ static int cha_getc_server(fp)
     return c;
 }
 
-static int cha_ungetc_server(c, fp)
-    int c;
-    FILE *fp;
+static int cha_ungetc_server(int c, FILE *fp)
 {
     c_stacked = c;
     return c;
 }
 
-void cha_set_getc_alone()
+void cha_set_getc_alone(void)
 {
-    int fgetc(), ungetc();
+    extern int fgetc(FILE*);
+    extern int ungetc(int, FILE*);
 
     cha_getc = fgetc;
     cha_ungetc = ungetc;
 }
 
-void cha_set_getc_server()
+void cha_set_getc_server(void)
 {
     cha_getc = cha_getc_server;
     cha_ungetc = cha_ungetc_server;
@@ -117,14 +116,13 @@ void cha_set_getc_server()
 /*
  * error_in_lisp
  */
-static chasen_cell_t *error_in_lisp()
+static chasen_cell_t *error_in_lisp(void)
 {
     cha_exit_file(1, "premature end of file or string\n");
     return NIL;
 }
 
-void cha_set_skip_char(c)
-    int c;
+void cha_set_skip_char(int c)
 {
     c_skip = c;
 }
@@ -133,9 +131,7 @@ void cha_set_skip_char(c)
  * ifnextchar - if next char is <c> return 1, otherwise return 0
  */
 #define ifnextchar(fp, ch)  ifnextchar2(fp, ch, 0)
-static int ifnextchar2(fp, ch1, ch2)
-    FILE *fp;
-    int ch1, ch2;
+static int ifnextchar2(FILE *fp, int ch1, int ch2)
 {
     int c;
 
@@ -155,8 +151,7 @@ static int ifnextchar2(fp, ch1, ch2)
 /*
  * skip comment lines
  */
-static int skip_comment(fp)
-    FILE *fp;
+static int skip_comment(FILE *fp)
 {
     int n, c;
 
@@ -170,8 +165,7 @@ static int skip_comment(fp)
     return n;
 }
 
-int cha_s_feof(fp)
-    FILE *fp;
+int cha_s_feof(FILE *fp)
 {
     int c;
 
@@ -204,8 +198,7 @@ int cha_s_feof(fp)
 
 #define malloc_cell()  malloc_free_cell(0)
 #define free_cell()    malloc_free_cell(1)
-static chasen_cell_t *malloc_free_cell(isfree)
-    int isfree;
+static chasen_cell_t *malloc_free_cell(int isfree)
 {
     static chasen_cell_t *ptr[1024*16];
     static int ptr_num = 0;
@@ -236,8 +229,7 @@ static chasen_cell_t *malloc_free_cell(isfree)
 
 #define CHA_MALLOC_SIZE (1024 * 64)
 #define free_char()  malloc_char(-1)
-static void *malloc_char(size)
-    int size;
+static void *malloc_char(int size)
 {
     static char *ptr[128];
     static int ptr_num = 0;
@@ -263,8 +255,7 @@ static void *malloc_char(size)
     }
 }
 
-static char *lisp_strdup(str)
-    char *str;
+static char *lisp_strdup(char *str)
 {
     char *newstr;
 
@@ -274,8 +265,7 @@ static char *lisp_strdup(str)
     return newstr;
 }
 
-void cha_s_free(cell)
-    chasen_cell_t *cell;
+void cha_s_free(chasen_cell_t *cell)
 {
 #if 1
     free_cell();
@@ -297,8 +287,7 @@ void cha_s_free(cell)
 /*
  * cha_tmp_atom
  */
-chasen_cell_t *cha_tmp_atom(atom)
-    char *atom;
+chasen_cell_t *cha_tmp_atom(char *atom)
 {
     static chasen_cell_t _TmpCell;
     static chasen_cell_t *TmpCell = &_TmpCell;
@@ -312,8 +301,7 @@ chasen_cell_t *cha_tmp_atom(atom)
 /*
  * cha_cons
  */
-chasen_cell_t *cha_cons(cha_car, cha_cdr)
-    void *cha_car, *cha_cdr;
+chasen_cell_t *cha_cons(void *cha_car, void *cha_cdr)
 {
     chasen_cell_t *cell;
 
@@ -328,8 +316,7 @@ chasen_cell_t *cha_cons(cha_car, cha_cdr)
 /*
  * cha_car
  */
-chasen_cell_t *cha_car(cell)
-    chasen_cell_t *cell;
+chasen_cell_t *cha_car(chasen_cell_t *cell)
 {
     if (consp(cell))
       return car_val(cell);
@@ -346,8 +333,7 @@ chasen_cell_t *cha_car(cell)
 /*
  * cha_cdr
  */
-chasen_cell_t *cha_cdr(cell)
-    chasen_cell_t *cell;
+chasen_cell_t *cha_cdr(chasen_cell_t *cell)
 {
     if (consp(cell))
       return cdr_val(cell);
@@ -360,8 +346,7 @@ chasen_cell_t *cha_cdr(cell)
     return NIL;
 }
 
-char *cha_s_atom(cell)
-    chasen_cell_t *cell;
+char *cha_s_atom(chasen_cell_t *cell)
 {
     if (atomp(cell))
       return s_atom_val(cell);
@@ -374,8 +359,7 @@ char *cha_s_atom(cell)
 /*
  * cha_equal
  */
-int cha_equal(x, y)
-    void *x, *y;
+int cha_equal(void *x, void *y)
 {
     if (eq(x, y)) return TRUE;
     if (nullp(x) || nullp(y)) return FALSE;
@@ -386,8 +370,7 @@ int cha_equal(x, y)
     return FALSE;
 }
 
-int cha_s_length(list)
-    chasen_cell_t *list;
+int cha_s_length(chasen_cell_t *list)
 {
     int i;
 
@@ -397,8 +380,7 @@ int cha_s_length(list)
     return i;
 }
 
-static int dividing_code_p(code)
-    int code;
+static int dividing_code_p(int code)
 {
     switch (code) {
       case '\n': case '\t': case ';': 
@@ -409,9 +391,7 @@ static int dividing_code_p(code)
     }
 }
 
-static int myscanf(fp, str)
-    FILE *fp;
-    char *str;
+static int myscanf(FILE *fp, char *str)
 {
     int code;
     int in_quote = 0;
@@ -466,8 +446,7 @@ static int myscanf(fp, str)
  * cha_s_read - read S-expression
  */
 
-static chasen_cell_t *s_read_atom(fp)
-    FILE *fp;
+static chasen_cell_t *s_read_atom(FILE *fp)
 {
     chasen_cell_t *cell;
     char buffer[BUFSIZ];
@@ -488,11 +467,10 @@ static chasen_cell_t *s_read_atom(fp)
     return cell;
 }
 
-static chasen_cell_t *s_read_cdr();
-static chasen_cell_t *s_read_main();
+static chasen_cell_t *s_read_cdr(FILE*);
+static chasen_cell_t *s_read_main(FILE*);
 
-static chasen_cell_t *s_read_car(fp)
-    FILE *fp;
+static chasen_cell_t *s_read_car(FILE *fp)
 {
     chasen_cell_t *cell;
 
@@ -511,8 +489,7 @@ static chasen_cell_t *s_read_car(fp)
     }
 }
 
-static chasen_cell_t *s_read_cdr(fp)
-    FILE *fp;
+static chasen_cell_t *s_read_cdr(FILE *fp)
 {
     skip_comment(fp);
 
@@ -526,8 +503,7 @@ static chasen_cell_t *s_read_cdr(fp)
     }
 }
 
-static chasen_cell_t *s_read_main(fp)
-    FILE *fp;
+static chasen_cell_t *s_read_main(FILE *fp)
 {
     /* skip_comment(fp); */
 
@@ -541,8 +517,7 @@ static chasen_cell_t *s_read_main(fp)
     }
 }
 
-chasen_cell_t *cha_s_read(fp)
-    FILE *fp;
+chasen_cell_t *cha_s_read(FILE *fp)
 {
     /* init the pointer to output functions */
     if (cha_getc == NULL)
@@ -559,8 +534,7 @@ chasen_cell_t *cha_s_read(fp)
  * cha_assoc
  */
 
-chasen_cell_t *cha_assoc(item, alist)
-    chasen_cell_t *item, *alist;
+chasen_cell_t *cha_assoc(chasen_cell_t *item, chasen_cell_t *alist)
 {
     while (!nullp(alist) && !cha_equal(item, (cha_car(cha_car(alist)))))
       alist = cha_cdr(alist);
@@ -572,10 +546,9 @@ chasen_cell_t *cha_assoc(item, alist)
  */
 
 static char cell_buffer_for_print[8192];
-static char *s_tostr_main();
+static char *s_tostr_main(chasen_cell_t*);
 
-static void s_puts_to_buffer(str)
-    char *str;
+static void s_puts_to_buffer(char *str)
 {
     static int idx = 0;
     int len;
@@ -596,8 +569,7 @@ static void s_puts_to_buffer(str)
     }
 }
 
-static void s_tostr_cdr(cell)
-    chasen_cell_t *cell;
+static void s_tostr_cdr(chasen_cell_t *cell)
 {
     if (!nullp(cell)) {
 	if (consp(cell)) {
@@ -611,8 +583,7 @@ static void s_tostr_cdr(cell)
     }
 }
 
-static char *s_tostr_main(cell)
-    chasen_cell_t *cell;
+static char *s_tostr_main(chasen_cell_t *cell)
 {
     if (nullp(cell))
       s_puts_to_buffer(NILSYMBOL);
@@ -635,8 +606,7 @@ static char *s_tostr_main(cell)
     return cell_buffer_for_print;
 }
 
-char *cha_s_tostr(cell)
-    chasen_cell_t *cell;
+char *cha_s_tostr(chasen_cell_t *cell)
 {
     /* initialization */
     s_puts_to_buffer(NULL);
@@ -644,11 +614,8 @@ char *cha_s_tostr(cell)
     return s_tostr_main(cell);
 }
 
-chasen_cell_t *cha_s_print(fp, cell)
-    FILE *fp;
-    chasen_cell_t *cell;
+chasen_cell_t *cha_s_print(FILE *fp, chasen_cell_t *cell)
 {
     fputs(cha_s_tostr(cell), fp);
     return cell;
 }
-
