@@ -1,7 +1,9 @@
-/*-
+/*
  * parse.c - parse a sentence
  *
- * Copyright (c) 1996, 1997, 2000 Nara Institute of Science and Technology
+ * Copyright (C) 1996, 1997, 2000, 2001, 
+ *                            Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -34,8 +36,7 @@
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
  * Modified by: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Oct. 1996
- *
- * $Id: parse.c,v 1.13.4.1 2000/12/18 20:08:31 masayu-a Exp $
+ * $Id: parse.c,v 1.19 2001/02/23 12:51:34 kazuma-t Exp $
  */
 
 #include "chalib.h"
@@ -72,8 +73,7 @@ int Cha_path_num;
 #define malloc_short(n)    malloc_chars(2, n)
 #define malloc_int(n)      malloc_chars(4, n)
 #define free_chars()       malloc_chars(0, 0)
-static void *malloc_chars(size, nitems)
-    int nitems, size;
+static void *malloc_chars(int size, int nitems)
 {
     static char *buffer_ptr[128];
     static int buffer_ptr_num = 0;
@@ -106,9 +106,7 @@ static void *malloc_chars(size, nitems)
     }
 }
 
-static void *malloc_free_block(ptr, nblockp, size, do_free)
-    void *ptr;
-    int *nblockp, size, do_free;
+static void *malloc_free_block(void *ptr, int *nblockp, int size, int do_free)
 {
     if (do_free) {
 	/* free and malloc one block */
@@ -154,8 +152,7 @@ static void *malloc_free_block(ptr, nblockp, size, do_free)
 
 #define malloc_path()  malloc_free_path(0)
 #define free_path()    malloc_free_path(1)
-static int malloc_free_path(do_free)
-    int do_free;
+static int malloc_free_path(int do_free)
 {
     static int nblock = 0;
 
@@ -171,8 +168,7 @@ static int malloc_free_path(do_free)
 
 #define malloc_mrph()  malloc_free_mrph(0)
 #define free_mrph()    malloc_free_mrph(1)
-static int malloc_free_mrph(do_free)
-    int do_free;
+static int malloc_free_mrph(int do_free)
 {
     static int nblock = 0;
 
@@ -189,8 +185,7 @@ static int malloc_free_mrph(do_free)
 /***********************************************************************
  * check_code()
  ***********************************************************************/
-static int check_code(str)
-    char *str;
+static int check_code(char *str)
 {
     int	code;
     unsigned char *s = (unsigned char *)str;
@@ -231,8 +226,7 @@ static int check_code(str)
  * Ҥ餬ʡ޻ʤ: 1ʸ
  * : Ϣ³ʸ
  ************************************************************************/
-static int undef_mrph_len(target)
-    char *target;
+static int undef_mrph_len(char *target)
 {
     int code, next_code;
     int len = 0;
@@ -259,9 +253,7 @@ static int undef_mrph_len(target)
 /***********************************************************************
  * register_undef_mrph1 - ̤Хåեɲ
  ***********************************************************************/
-static int register_undef_mrph1(target, mrph_idx, undef_len, no)
-    char *target;
-    int mrph_idx, undef_len, no;
+static int register_undef_mrph1(char *target, int mrph_idx, int undef_len, int no)
 {
 #if 0
     int undef_len;
@@ -300,9 +292,7 @@ static int register_undef_mrph1(target, mrph_idx, undef_len, no)
 }
 
 #if 0
-static int register_undef_mrph(target, mrph_idx, undef_len)
-    char *target;
-    int mrph_idx, undef_len;
+static int register_undef_mrph(char *target, int mrph_idx, int undef_len)
 {
     int no;
 
@@ -404,8 +394,7 @@ static int convert_mrphs(char *target, char **dic_buffer, int mrph_idx)
 /*
  * collect_mrphs_for_pos()
  */
-static int collect_mrphs_for_pos(pos, p_idx)
-    int pos, *p_idx;
+static int collect_mrphs_for_pos(int pos, int *p_idx)
 {
     static int p_start;
     int i, j;
@@ -433,8 +422,7 @@ static int collect_mrphs_for_pos(pos, p_idx)
 /***********************************************************************
  * check_connect()
  ***********************************************************************/
-static int check_connect(pos, m_num, p_idx)
-    int pos, m_num, *p_idx;
+static int check_connect(int pos, int m_num, int *p_idx)
 {
     /* ֤ͤǥѥʬह */
     typedef struct _path_cost_t {
@@ -474,11 +462,6 @@ static int check_connect(pos, m_num, p_idx)
 	/* ȥޥȥĴ٤Ƽ֤³ȤФ */
 	next_state = cha_check_automaton
 	  (Cha_path[pno].state,
-#ifdef KOCHA
-	   Cha_path[Cha_path[pno].path[0]].state,
-	   Cha_mrph[Cha_path[pno].mrph_p].midasi,
-	   Cha_mrph[Cha_path[pno].mrph_p].is_undef,
-#endif
 	   con_tbl, Cha_con_cost_undef, &con_cost);
 
 	if (con_cost == -1) continue;
@@ -533,30 +516,6 @@ static int check_connect(pos, m_num, p_idx)
     }
     mrph_cost *= new_mrph->weight * Cha_mrph_cost_weight;
 
-#ifdef KOCHA
-    if (new_mrph->midasi &&
-	(unsigned char)new_mrph->midasi[0] == 0xA1 &&
-	(unsigned char)new_mrph->midasi[1] == 0xA1) {
-	for (i = 0; i < pcost[0].num; i++) {
-	    int *new_path;
-	    Cha_path[Cha_path_num].path = malloc_int(2);
-	    Cha_path[Cha_path_num].path[0] = pcost[0].pno[i];
-	    Cha_path[Cha_path_num].path[1] = -1;
-
-	    Cha_path[Cha_path_num].cost = pcost[0].cost[i] + mrph_cost;
-	    Cha_path[Cha_path_num].mrph_p = m_num;
-	    Cha_path[Cha_path_num].state = pcost[0].state;
-	    Cha_path[Cha_path_num].start = pos;
-	    Cha_path[Cha_path_num].end = pos + new_mrph->length;
-#ifdef KOCHA_DEBUG
-	    printf("[Sp:%d,prev:%d,m:%d,c:%d,pc:%d]\n",
-		   Cha_path_num,Cha_path[Cha_path_num].path[0],m_num,pcost[0].cost[i],Cha_path[Cha_path_num].cost);
-#endif
-	    if (++Cha_path_num % CHA_PATH_NUM == 0 && malloc_path())
-	      return FALSE;
-	}
-    } else {
-#endif /* KOCHA */
 #if 0
 	if (Cha_path[Cha_path_num].end == pos + new_mrph->length &&
 	    Cha_path[Cha_path_num].state == pcost[pcostno].state &&
@@ -614,14 +573,11 @@ static int check_connect(pos, m_num, p_idx)
 	    if (++Cha_path_num % CHA_PATH_NUM == 0 && malloc_path())
 	      return FALSE;
 	}
-#ifdef KOCHA
-    }
-#endif
+
     return TRUE;
 }
 
-static void set_mrph_end(mrph)
-    mrph2_t *mrph;
+static void set_mrph_end(mrph2_t *mrph)
 {
     mrph->midasi = mrph->yomi = mrph->info = "";
     mrph->base = mrph->pron = "";
@@ -636,7 +592,7 @@ static void set_mrph_end(mrph)
     mrph->weight = MRPH_DEFAULT_WEIGHT;
 }
 
-static int set_mrph_bkugiri()
+static int set_mrph_bkugiri(void)
 {
     static int bkugiri_num;
     int h;
@@ -666,8 +622,7 @@ static int set_mrph_bkugiri()
     return bkugiri_num;
 }
 
-static int strcmp_anno(target)
-    char *target;
+static int strcmp_anno(char *target)
 {
     int i;
 
@@ -678,15 +633,14 @@ static int strcmp_anno(target)
 }
 
 /*
- * check_undefword_len()
+ * euc_check_undefword_len()
  *
  * type: -n(n=idx of Cha_anno_info) / 0(space) / 1(1byte) / 2(2byte) / 3(3byte)
  * stat: -n(n=idx of Cha_anno_info) / 0(space) / 1(e:[a-zA-Z],j:1byte)
  *       / 2(katakana) / 3(alphabet) / 4(otherwise)
  */
-static void check_undefword_len(target, undefword_len, char_type, target_len)
-    char *target, *char_type;
-    short *undefword_len;
+static void euc_check_undefword_len(char *target, short *undefword_len,
+				    char *char_type, int target_len)
 {
     unsigned char *t;
     short *ulen0, *ulen;
@@ -720,7 +674,7 @@ static void check_undefword_len(target, undefword_len, char_type, target_len)
 	    /*: (!(*t & 0x80) && !(*t>='0'&&*t<='9'||*t=='.'||*t==','))) {*/
 	    /* [a-zA-Z] / [^1-9.,] */
 	    stat = 1;
-	} else if (/* znekaku chou-on */
+	} else if (/* zenkaku chou-on */
 		   (stat0 == 2 && t[0] == 0xa1 && t[1] == 0xbc) ||
 		   /* 0xa5a1-0xa5ff: zenkaku katakana */
 		   (t[0] == 0xa5 && t[1] >= 0xa1 &&
@@ -768,6 +722,189 @@ static void check_undefword_len(target, undefword_len, char_type, target_len)
     *ulen0 = ulen - ulen0;
 }
 
+/*
+ * utf8_check_undefword_len()
+ *
+ * type: -n(n=idx of Cha_anno_info) /
+ * 0(space) / 1(1byte) / 2(2byte) / 3(3byte) / 4(4byte)
+ * stat: -n(n=idx of Cha_anno_info) / 0(space) / 1(e:[a-zA-Z],j:1byte)
+ *       / 2(katakana) / 3(alphabet) / 4(otherwise)
+ */
+static void utf8_check_undefword_len(char *target, short *undefword_len,
+				     char *char_type, int target_len)
+{
+    unsigned char *t;
+    short *ulen0, *ulen;
+    char *type;
+    int stat0 = 1, stat = 0;
+    anno_info *anno = NULL;
+
+    memset(undefword_len, 0, target_len * sizeof(short));
+    memset(char_type, 1, target_len + 1);
+
+    t = (unsigned char *)target;
+    ulen0 = ulen = undefword_len;
+    type = char_type;
+
+    while ((char *)t < target + target_len) {
+	if (stat0 < 0 &&
+	    (anno->len2 == 0 ||
+	     ((char *)t - target > anno->len2 &&
+	     !memcmp(t - anno->len2, anno->str2, anno->len2))))
+	  stat0 = 99;
+	if (stat0 < 0) {
+	    ;
+	} else if (is_spc(*t)) {
+	    *type = stat = 0;
+	} else if ((stat = strcmp_anno(t)) < 0) {
+	    *type = stat;
+	    anno = &Cha_anno_info[-stat];
+	} else if (Cha_lang_e
+		   ? ((*t>='a' && *t<='z') || (*t>='A' && *t<='Z'))
+		   : !(*t & 0x80) /* (not in GR) == GL */
+	    ) {
+	    stat = 1;
+	} else if (/* KATAKANA-HIRAGANA PROLONGED SOUND MARK
+		      U+30FC */
+		   (stat0 == 2 &&
+		    t[0] == 0xe3 && t[1] == 0x83 && t[2] == 0xbc) ||
+		   /* KATAKANA LETTER (SMALL) [A-VO]
+		      U+30A1 -- U+30FA
+		      include VA, VI, VE, VO */
+		   ((t[0] == 0xe3 &&
+		     ((t[1] == 0x82 && t[2] >= 0xa1 && t[2] <= 0xbf) ||
+		      (t[1] == 0x83 && t[2] >= 0x80 && t[2] <= 0xBA))) &&
+		    !(stat0 != 2 &&
+		     /* KATAKANA LETTER SMALL AIUEO, TU, YAYUYO, WA and
+			KATAKANA-HIRAGANA PROLONGED SOUND MARK
+			U+30A1, U+30A3, U+30A5, U+30A7, U+30A9
+			U+30C3, U+30E3, U+30E5, U+30E7, U+30EE
+			U+30FC */
+		      (t[0] == 0xe3 &&
+		       ((t[1] == 0x82 &&
+			 (t[2] == 0xa1 || t[2] == 0xa3 || t[2] == 0xa5 ||
+			  t[2] == 0xa7 || t[2] == 0xa9)) ||
+			(t[1] == 0x83 &&
+			 (t[2] == 0x83 || t[2] == 0xa3 || t[2] == 0xa5 ||
+			  t[2] == 0xa7 || t[2] == 0xae ||
+			  t[2] == 0xbc))))))) {
+	    stat = 2;
+	} else if (t[0] == 0xef &&
+		   ((t[1] == 0xbc && t[2] >= 0xa1 && t[2] <= 0xba) ||
+		    (t[1] == 0xbd && t[2] >= 0x81 && t[2] <= 0x9a))) {
+	    /* FULLWIDTH LATIN (CAPITAL|SMALL) LETTER [A-Z]
+	       U+FF21 -- U+FF3A, U+FF41 -- U+FF5A */
+	    stat = 3;
+	} else {
+	    stat = 4;
+	    stat0 = 99;
+	}
+
+        if (stat != stat0) {
+	    *ulen0 = ulen - ulen0;
+	    ulen0 = ulen;
+	}
+
+	if (stat < 0 && stat != stat0) {
+	    int len = anno->len1 + anno->len2;
+	    if (len > target_len - ((char *)t - target))
+	      len = target_len - ((char *)t - target);
+	    t += len;
+	    ulen += len;
+	    type += len;
+	} else if ((t[0] & 0xf0) == 0xf0 &&
+		   (t[1] & 0x80) && (t[2] & 0x80) && (t[3] & 0x80)) {
+	    *type = 4;
+	    t += 4; ulen += 4, type += 4;
+	} else if ((t[0] & 0xe0) == 0xe0 &&
+		   (t[1] & 0x80) && (t[2] & 0x80)) {
+	    *type = 3;
+	    t += 3; ulen += 3, type += 3;
+	} else if ((t[0] & 0xc0) == 0xc0 && (t[1] & 0x80)) {
+	    *type = 2;
+	    t += 2; ulen += 2, type += 2;
+	} else {
+	    t++; ulen++, type++;
+	}
+	stat0 = stat;
+    }
+
+    *ulen0 = ulen - ulen0;
+}
+
+/*
+ * iso8859_check_undefword_len()
+ *
+ * type: -n(n=idx of Cha_anno_info) /
+ * 0(space) / 1(1byte)
+ * stat: -n(n=idx of Cha_anno_info) / 0(space) / 1(otherwise)
+ */
+static void iso8859_check_undefword_len(char *target, short *undefword_len,
+					char *char_type, int target_len)
+{
+    unsigned char *t;
+    short *ulen0, *ulen;
+    char *type;
+    int stat0 = 1, stat = 0;
+    anno_info *anno = NULL;
+
+    memset(undefword_len, 0, target_len * sizeof(short));
+    memset(char_type, 1, target_len + 1);
+
+    t = (unsigned char *)target;
+    ulen0 = ulen = undefword_len;
+    type = char_type;
+
+    while ((char *)t < target + target_len) {
+	if (stat0 < 0 &&
+	    (anno->len2 == 0 ||
+	     ((char *)t - target > anno->len2 &&
+	     !memcmp(t - anno->len2, anno->str2, anno->len2))))
+	  stat0 = 99;
+	if (stat0 < 0) {
+	    ;
+	} else if (is_spc(*t)) {
+	    *type = stat = 0;
+	} else if ((stat = strcmp_anno(t)) < 0) {
+	    *type = stat;
+	    anno = &Cha_anno_info[-stat];
+	} else {
+	    stat = 1;
+	}
+
+        if (stat != stat0) {
+	    *ulen0 = ulen - ulen0;
+	    ulen0 = ulen;
+	}
+
+	if (stat < 0 && stat != stat0) {
+	    int len = anno->len1 + anno->len2;
+	    if (len > target_len - ((char *)t - target))
+	      len = target_len - ((char *)t - target);
+	    t += len;
+	    ulen += len;
+	    type += len;
+ 	} else {
+	    t++; ulen++, type++;
+	}
+	stat0 = stat;
+    }
+
+    *ulen0 = ulen - ulen0;
+}
+
+static int is_jisx0208_alphabet(unsigned char *t)
+{
+    if (Cha_encode == CHA_ENCODE_EUC) {
+	return (t[0] == 0xa3 && t[1] >= 0xc1);
+    } else if (Cha_encode == CHA_ENCODE_UTF8) {
+	return (t[0] == 0xef &&
+		((t[1] == 0xbc && t[2] >= 0xa1 && t[2] <= 0xba) ||
+		 (t[1] == 0xbd && t[2] >= 0x81 && t[2] <= 0x9a)));
+    }
+    return 0;
+}
+
 /***********************************************************************
  * cha_parse_sentence() - ʸǲϤ
  *
@@ -775,10 +912,7 @@ static void check_undefword_len(target, undefword_len, char_type, target_len)
  *     0 - ok
  *     1 - no result / too many morphs
  ***********************************************************************/
-int cha_parse_sentence(target, target_len, opt_nobk)
-    char *target;
-    int target_len; /* should be >0 */
-    int opt_nobk;
+int cha_parse_sentence(char *target, int target_len, int opt_nobk)
 {
     int  i, dic_no;
     int  pos, pos_end;
@@ -789,9 +923,22 @@ int cha_parse_sentence(target, target_len, opt_nobk)
     static int path0 = -1;
     char *dic_buffer[256];
     static short undefword_len[CHA_INPUT_SIZE];
-    static char char_type[CHA_INPUT_SIZE];
+    static char char_type[CHA_INPUT_SIZE + 3];
+
+    if (Cha_encode == CHA_ENCODE_EUC) {
+	euc_check_undefword_len(target, undefword_len,
+				char_type, target_len);
+    } else if (Cha_encode == CHA_ENCODE_EUC) {
+	utf8_check_undefword_len(target, undefword_len,
+				 char_type, target_len);
+    } else if (Cha_encode == CHA_ENCODE_ISO8859) {
+	iso8859_check_undefword_len(target, undefword_len,
+				    char_type, target_len);
+    } else {
+	iso8859_check_undefword_len(target, undefword_len,
+				    char_type, target_len);
+    }
 
-    check_undefword_len(target, undefword_len, char_type, target_len);
     cha_set_sentence(target, undefword_len, char_type);
 
     free_chars();
@@ -812,11 +959,10 @@ int cha_parse_sentence(target, target_len, opt_nobk)
     new_mrph_idx = mrph_idx = bkugiri_num + 1;
 
     for (pos = pos_end = 0; pos < target_len;
-	 pos += char_type[pos] == 2 &&
-	 !((unsigned char)target[pos] == 0xa3 &&
-	 (unsigned char)target[pos+1] >= 0xc1)
-	 ? 2 : undefword_len[pos],
-	 pos_end = pos) {
+	 pos += 
+	     ((char_type[pos] >= 2 && !is_jisx0208_alphabet(target + pos))
+	      ? char_type[pos] : undefword_len[pos]),
+	     pos_end = pos) {
 #if 0
 	printf("# mrph %d\n", mrph_idx);
 #endif
@@ -851,8 +997,8 @@ int cha_parse_sentence(target, target_len, opt_nobk)
 	}
 #endif
 
-	/* (ʸΤ߸) */
-	if (char_type[pos] == 2) {
+	/* (ʸΤ߸) EUC only */
+	if (Cha_encode == CHA_ENCODE_EUC && char_type[pos] == 2) {
 	    for (dic_no = 0; dic_no < Pat_ndicfile; dic_no++) {
 		int nmrph;
 		/* ѥȥꥷڤǤ򸡺 */
@@ -871,7 +1017,7 @@ int cha_parse_sentence(target, target_len, opt_nobk)
 	    int nmrph;
 	    /* SUFARY ե뤫Ǥ򸡺 */
 	    sa_common_prefix_search(Suf_dicfile[dic_no],
-				    target + pos,
+				    target + pos, char_type + pos,
 				    dic_buffer);
 	    /* ѤĤķǤ Cha_mrph ɲ */
 	    nmrph = convert_mrphs(target + pos, dic_buffer,
@@ -960,4 +1106,3 @@ int cha_parse_sentence(target, target_len, opt_nobk)
 #endif
     return 1;
 }
-
