@@ -1,7 +1,9 @@
-/*-
- * pat.c
+/*
+ * pat.c - library for patricia tree
  *
- * Copyright (c) 1996, 1997, 2000 Nara Institute of Science and Technology
+ * Copyright (C) 1996, 1997, 2000, 2001, 
+ *                            Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,7 +35,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: pat.c,v 1.8.4.1 2000/12/18 20:08:31 masayu-a Exp $
+ * $Id: pat.c,v 1.11 2001/02/14 00:20:53 masayu-a Exp $
  */
 
 #include <stdio.h>
@@ -97,7 +99,7 @@ static int pat_memcmp(unsigned char *s1, unsigned char *s2, int n)
 
 /* key  checkbitӥåܤǺ˿ʬ */
 #define get_next_node(node, key, checkbit, key_length) \
-(pat_bits((key), (checkbit), (key_length))) ? (node)->right : (node)->left
+((pat_bits((key), (checkbit), (key_length))) ? (node)->right : (node)->left)
 
 /****************************************************
 * pat_search --- ѥȥꥷڤ򸡺
@@ -250,12 +252,11 @@ static pat_node *pat_search4insert(char *key, pat_node *node)
 *   line --- ǡ(ƤڤʸǶڤƤ빽¤)
 *   index --- ǡΥեΥǥå
 *   x_ptr --- Τθγϰ
-*   kugiri --- Ƥζڤʸ
 * 
 * ֤
 *   ̵!
 ****************************************************/
-void pat_insert(pat_t *pat, char *line, long index, char *kugiri)
+void pat_insert(pat_t *pat, char *line, long index)
 {
     pat_node *x_ptr = pat->root;
     pat_node *t_ptr, *p_ptr, *new_ptr;
