@@ -1,7 +1,9 @@
-/*-
- * patfile.c
+/*
+ * patfile.c - library for patricia tree
  *
- * Copyright (c) 1996, 1997, 2000 Nara Institute of Science and Technology
+ * Copyright (C) 1996, 1997, 2000, 2001, 
+ *                            Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,9 +35,8 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: patfile.c,v 1.5.4.1 2000/12/18 20:08:31 masayu-a Exp $
+ * $Id: patfile.c,v 1.10 2001/02/14 00:20:53 masayu-a Exp $
  */
-
 #include "config.h"
 #include <stdio.h>
 #ifndef _WIN32
@@ -44,15 +45,9 @@
 #include <fcntl.h>
 #include <stdlib.h>
 
-#if ! defined _WIN32 && ! defined __CYGWIN__
-#define O_BINARY 0
-#endif
-
 #include "chadic.h"
 #include "pat.h"
 
-#define PAT_BUFSIZ 1024
-
 pat_node *pat_malloc_node(void);
 static void pat_init_tree_top(pat_node*);
 static void pat_com_l(char*, pat_node*);
@@ -67,8 +62,8 @@ pat_t *pat_open(char *textfile, char *patfile)
     void *map;
 
     pat = cha_malloc(sizeof(pat_t));
-    pat->size = cha_mmap_file(textfile, &map);
-    pat->map = map;
+    pat->_size = cha_mmap_file(textfile, &map);
+    pat->_map = map;
     pat->root = pat_malloc_node();
     pat_init_tree_top(pat->root);
 
@@ -92,10 +87,10 @@ void pat_text_reopen(pat_t *pat, char *textfile)
 {
     void *map;
 
-    cha_munmap_file(pat->map, pat->size);
+    cha_munmap_file(pat->_map, pat->_size);
     pat = cha_malloc(sizeof(pat_t));
-    pat->size = cha_mmap_file(textfile, &map);
-    pat->map = map;    
+    pat->_size = cha_mmap_file(textfile, &map);
+    pat->_map = map;    
 }
 
 /*
@@ -127,47 +122,12 @@ pat_node *pat_malloc_node(void)
     return ptr + idx++;
 }
 
-static void eputc(int c, int file_discripter)
+static void dummy(FILE *fp)
 {
-    static int ctr = 0;
-    static unsigned char buf[PAT_BUFSIZ];
-
-    buf[ctr] = c;
-    ctr++;
-
-    if (ctr == PAT_BUFSIZ) {
-	ctr = 0;
-	write(file_discripter, buf, PAT_BUFSIZ);
-    }
-
-    return;
-}
-
-static void dummy(int fd)
-{
-    eputc(0xff,fd);
-    eputc(0xff,fd);
-    eputc(0xff,fd);
-    eputc(0xff,fd);
-}
-
-static unsigned char egetc(int fd)
-{
-    static int fd_check = -1;
-    static char buf[PAT_BUFSIZ];
-    static int ctr = sizeof(buf) - 1;
-
-    if (fd != fd_check) { /* Хåեν */
-	fd_check = fd;
-	ctr = sizeof(buf) - 1;
-    }
-
-    if (++ctr == sizeof(buf)){
-	ctr = 0;
-	read(fd, buf, sizeof(buf));
-    }
-
-    return(buf[ctr]);
+    fputc(0xff,fp);
+    fputc(0xff,fp);
+    fputc(0xff,fp);
+    fputc(0xff,fp);
 }
 
 /****************************************************
@@ -189,7 +149,7 @@ static unsigned char egetc(int fd)
 * 
 *   ǥåγǼ꤬Ȱ㤦äʤ
 *************************************************************************/
-static pat_node *pat_load_anode(pat_node *p_ptr, int fd)
+static pat_node *pat_load_anode(pat_node *p_ptr, FILE *fp)
 {
     unsigned char c;
     pat_node *new_ptr; /* äΡ(==ΥΡ)ؤݥ */
@@ -201,12 +161,12 @@ static pat_node *pat_load_anode(pat_node *p_ptr, int fd)
     if (!(++dbg%1000))printf("%d,",dbg);
 #endif
 
-    if ((c = egetc(fd)) & 0x80) { /* դäѤνǥåɤ߹ */
+    if ((c = fgetc(fp)) & 0x80) { /* դäѤνǥåɤ߹ */
 	while (c & 0x80) {
 	    tmp_idx = (c & 0x3f) << 24;
-	    tmp_idx |= egetc(fd) << 16;
-	    tmp_idx |= egetc(fd) << 8;
-	    tmp_idx |= egetc(fd);
+	    tmp_idx |= fgetc(fp) << 16;
+	    tmp_idx |= fgetc(fp) << 8;
+	    tmp_idx |= fgetc(fp);
 
 	    if ((p_ptr->il).index < 0)
 		new_l_ptr = &(p_ptr->il);
@@ -219,19 +179,19 @@ static pat_node *pat_load_anode(pat_node *p_ptr, int fd)
 	    t_ptr = new_l_ptr;
 
 	    if (c & 0x40) break;
-	    c = egetc(fd);
+	    c = fgetc(fp);
 	}
 
 	return (p_ptr);
     } else { /* νƵ */
 	new_ptr = pat_malloc_node();
-	new_ptr->checkbit = ((c << 8) | egetc(fd)) - 1; /* åӥå */
+	new_ptr->checkbit = ((c << 8) | fgetc(fp)) - 1; /* åӥå */
 #if 0
 	printf("#cb %d\n",new_ptr->checkbit);
 #endif
 	(new_ptr->il).index = -1;
-	new_ptr->left = pat_load_anode(new_ptr, fd);
-	new_ptr->right = pat_load_anode(p_ptr, fd);
+	new_ptr->left = pat_load_anode(new_ptr, fp);
+	new_ptr->right = pat_load_anode(p_ptr, fp);
 	return (new_ptr);
     }
 }
@@ -245,18 +205,18 @@ static pat_node *pat_load_anode(pat_node *p_ptr, int fd)
 ******************************************************/
 static void pat_com_l(char *fname_pat, pat_node *ptr)
 {
-    int fd;
+    FILE *fp;
 
 #if 0
     fprintf(stderr, "# Loading pat-tree \"%s\" ... ",fname_pat);
 #endif
 
-    if ((fd = open(fname_pat, O_RDONLY | O_BINARY)) == -1) {
+    if ((fp = fopen(fname_pat, "rb")) == NULL) {
 	fprintf(stderr, "can't open %s\n",fname_pat);
 	exit(1);
     }
-    ptr->right = pat_load_anode(ptr, fd);
-    close(fd);
+    ptr->right = pat_load_anode(ptr, fp);
+    fclose(fp);
 #if 0
     fprintf(stderr,"done.\n");
 #endif
@@ -279,49 +239,49 @@ static void pat_com_l(char *fname_pat, pat_node *ptr)
 *      -1 ΤȤΤ 1 ­
 *   ǥå ---  0 ӥåȤ 1 ˤ
 ****************************************************/
-static void save_pat(pat_node *top_ptr, int fd)
+static void save_pat(pat_node *top_ptr, FILE *fp)
 {
     pat_index_list *ptr;
 
     /* νåӥåȤ */
-    eputc (((top_ptr->checkbit + 1)>> 8) & 0x7f, fd);
-    eputc ((top_ptr->checkbit + 1)& 0xff, fd);
+    fputc (((top_ptr->checkbit + 1)>> 8) & 0x7f, fp);
+    fputc ((top_ptr->checkbit + 1)& 0xff, fp);
 
     /*  Subtree νդäѤʤ饤ǥåϡ
        դäѤǤʤкƵ*/
     if (top_ptr->checkbit < top_ptr->left->checkbit)
-	save_pat(top_ptr->left, fd);
+	save_pat(top_ptr->left, fp);
     else {
 	ptr = &(top_ptr->left->il);
 	if (ptr->index < 0) 
-	    dummy(fd);
+	    dummy(fp);
 	else {
 	    while (ptr != NULL) {
 		if (ptr->next == NULL)
-		    eputc (((ptr->index >> 24) & 0x3f) | 0xc0, fd);
+		    fputc (((ptr->index >> 24) & 0x3f) | 0xc0, fp);
 		else
-		    eputc (((ptr->index >> 24) & 0x3f) | 0x80, fd);
-		eputc ((ptr->index >> 16) & 0xff, fd);
-		eputc ((ptr->index >> 8) & 0xff, fd);
-		eputc ((ptr->index) & 0xff, fd);
+		    fputc (((ptr->index >> 24) & 0x3f) | 0x80, fp);
+		fputc ((ptr->index >> 16) & 0xff, fp);
+		fputc ((ptr->index >> 8) & 0xff, fp);
+		fputc ((ptr->index) & 0xff, fp);
 		ptr = ptr->next;
 	    }
 	}
     }
     if (top_ptr->checkbit < top_ptr->right->checkbit)
-	save_pat(top_ptr->right, fd);
+	save_pat(top_ptr->right, fp);
     else {
 	ptr = &(top_ptr->right->il);
-	if (ptr->index < 0) dummy(fd);
+	if (ptr->index < 0) dummy(fp);
 	else {
 	    while (ptr != NULL) {
 		if (ptr->next == NULL)
-		    eputc (((ptr->index >> 24) & 0x3f) | 0xc0, fd);
+		    fputc (((ptr->index >> 24) & 0x3f) | 0xc0, fp);
 		else
-		    eputc (((ptr->index >> 24) & 0x3f) | 0x80, fd);
-		eputc ((ptr->index >> 16) & 0xff, fd);
-		eputc ((ptr->index >> 8) & 0xff, fd);
-		eputc ((ptr->index) & 0xff, fd);
+		    fputc (((ptr->index >> 24) & 0x3f) | 0x80, fp);
+		fputc ((ptr->index >> 16) & 0xff, fp);
+		fputc ((ptr->index >> 8) & 0xff, fp);
+		fputc ((ptr->index) & 0xff, fp);
 		ptr = ptr->next;
 	    }
 	}
@@ -337,18 +297,16 @@ static void save_pat(pat_node *top_ptr, int fd)
 *****************************************************/
 static void pat_com_s(char *fname_pat, pat_node *ptr)
 {
-    int i, fd;
+    FILE *fp;
 
     printf("Saving pat-tree \"%s\" ...\n",fname_pat);
-    fd = open(fname_pat, O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0644);
-    if (fd < 0) {
+    fp = fopen(fname_pat, "w+b");
+    if (fp == NULL) {
 	fprintf(stderr, "can't open %s\n", fname_pat);
 	exit(1);
     }; 
-    save_pat(ptr->right, fd); /* ե */
-    for (i = 0; i < PAT_BUFSIZ; i++)
-	eputc(0, fd); /* flush */
-    close(fd);
+    save_pat(ptr->right, fp); /* ե */
+    fclose(fp);
 }
 
 /******************************************************
