@@ -1,7 +1,9 @@
-/*-
+/*
  * print.c - print mrphs and paths
  *
- * Copyright (c) 1996, 1997, 2000 Nara Institute of Science and Technology
+ * Copyright (C) 1996, 1997, 2000, 2001, 
+ *                            Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -33,12 +35,13 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * last modified by A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Sep. 1996
- *               by O.Imaichi <osamu-im@is.aist-nara.ac.jp>, Sep. 1996
- *
- * $Id: print.c,v 1.5.4.1 2000/12/18 20:08:31 masayu-a Exp $
+ *  modified by A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Sep. 1996
+ *           by O.Imaichi <osamu-im@is.aist-nara.ac.jp>, Sep. 1996
+ * $Id: print.c,v 1.9 2001/02/23 12:51:34 kazuma-t Exp $
  */
 
+#include <stdarg.h>
+#include <stdio.h>
 #include "chalib.h"
 #include "pat.h"
 
@@ -54,10 +57,7 @@ static char *char_type;
 static void (*cha_putc)(), (*cha_puts)(), (*cha_printf)();
 static void (*cha_fputc)(), (*cha_fputs)(), (*cha_fprintf)();
 
-void cha_set_sentence(str, lenp, typep)
-    char *str;
-    short *lenp;
-    char *typep;
+void cha_set_sentence(char *str, short *lenp, char *typep)
 {
     pos_end = 0;
     sentence = str;
@@ -69,9 +69,7 @@ void cha_set_sentence(str, lenp, typep)
  * cha_clputc, cha_clputs, cha_clprintf
  *	- output functions for ChaSen client
  */
-static void cha_clputc(c, output)
-    int c;
-    FILE *output;
+static void cha_clputc(int c, FILE *output)
 {
     if (is_bol && c == '.')
       putc('.', output);
@@ -81,9 +79,7 @@ static void cha_clputc(c, output)
     is_bol = c == '\n' ? 1 : 0;
 }
 
-static void cha_clputs(s, output)
-    char *s;
-    FILE *output;
+static void cha_clputs(char *s, FILE *output)
 {
     if (is_bol && s[0] == '.')
       putc('.', output);
@@ -93,13 +89,14 @@ static void cha_clputs(s, output)
     is_bol = s[strlen(s) - 1] == '\n' ? 1 : 0;    
 }
 
-static void cha_clprintf(output, format, a, b, c, d, e, f, g, h)
-    FILE *output;
-    char *format, *a, *b, *c, *d, *e, *f, *g, *h;
+static void cha_clprintf(FILE *output, char *format, ...)
 {
     char tmpbuf[CHA_INPUT_SIZE];
+    va_list ap;
 
-    sprintf(tmpbuf, format, a, b, c, d, e, f, g, h);
+    va_start(ap, format);
+    vsprintf(tmpbuf, format, ap);
+    va_end(ap);
 
     if (is_bol && tmpbuf[0] == '.')
       putc('.', output);
@@ -121,9 +118,7 @@ static char *cha_output;
 static int cha_output_idx;
 static int cha_output_nblock;
 
-static void cha_sputc(c, output)
-    int c;
-    char *output; /* dummy */
+static void cha_sputc(int c, char *output /* dummy */)
 {
     if (cha_output_idx + 1 >= CHA_OUTPUT_SIZE * cha_output_nblock
 	&& cha_output) {
@@ -136,9 +131,7 @@ static void cha_sputc(c, output)
     }
 }
 
-static void cha_sputs(s, output)
-    char *s;
-    char *output;
+static void cha_sputs(char *s, char *output)
 {
     int len = strlen(s);
 
@@ -153,26 +146,26 @@ static void cha_sputs(s, output)
     }
 }
 
-static void cha_sprintf(output, format, a, b, c, d, e, f, g, h)
-    char *output;
-    char *format, *a, *b, *c, *d, *e, *f, *g, *h;
+static void cha_sprintf(char *output, char *format, ...)
 {
     char tmpbuf[CHA_INPUT_SIZE];
+    va_list ap;
 
-    sprintf(tmpbuf, format, a, b, c, d, e, f, g, h);
+    va_start(ap, format);
+    vsprintf(tmpbuf, format, ap);
+    va_end(ap);
     cha_sputs(tmpbuf, output);
 }
 
-void cha_set_fput(server_mode)
-    int server_mode;
+void cha_set_fput(int server_mode)
 {
     /* 
      * For system having no prototype declarations for the following
      * functions such as SunOS 4.1.4. 
      */
-    extern int fputc();
-    extern int fputs();
-    extern int fprintf();
+    extern int fputc(int, FILE*);
+    extern int fputs(const char*, FILE*);
+    extern int fprintf(FILE*, const char*, ...);
 
     if (server_mode) {
 	cha_fputc = (void (*))cha_clputc;
@@ -185,8 +178,7 @@ void cha_set_fput(server_mode)
     }
 }
 
-void cha_set_output(output)
-    FILE *output;
+void cha_set_output(FILE *output)
 {
     if (output == NULL) {
 	/* output to string */
@@ -214,7 +206,7 @@ void cha_set_output(output)
 /*
  * returns cha_output for chasen_[fs]arse_tostr()
  */
-char *cha_get_output()
+char *cha_get_output(void)
 {
     return cha_output;
 }
@@ -285,25 +277,17 @@ char *cha_get_output()
  *	"%m %y %M %h %b %t %f\n"                     same as -c option
  *	"%m %U(%y) %M %H %h %B* %b %T* %t %F* %f\n"  same as -e option
  */
-static int check_con_cost(path, con_tbl)
-    path_t *path;
-    int con_tbl;
+static int check_con_cost(path_t *path, int con_tbl)
 {
     int con_cost;
 
     cha_check_automaton(path->state,
-#ifdef KOCHA
-		    Cha_path[path->path[0]].state,
-		    Cha_mrph[path->mrph_p].midasi,
-		    Cha_mrph[path->mrph_p].is_undef,
-#endif
-		    con_tbl, Cha_con_cost_undef, &con_cost);
+			con_tbl, Cha_con_cost_undef, &con_cost);
 
     return con_cost;
 }
 
-static int comm_prefix_len(s1, s2)
-    char *s1, *s2;
+static int comm_prefix_len(char *s1, char *s2)
 {
     char *s0 = s1;
     for (; *s1 && *s1 == *s2; s1++, s2++) {
@@ -314,16 +298,17 @@ static int comm_prefix_len(s1, s2)
     return s1 - s0;
 }
 
-static void set_ruby(dest, midasi, yomi, par1, par2, par3)
-    char *dest, *midasi, *yomi;
-    int par1, par2, par3;
+static void set_ruby(char *dest, char *midasi, char *yomi,
+		     int par1, int par2, int par3)
 {
     char *d = dest;
     char *m = midasi;
     char *y = yomi;
-    char *m0, *y0, *ymax;
+    char *m0 = NULL;
+    char *y0 = NULL;
+    char *ymax = NULL;
     int stat = 0;
-    int plen, maxplen;
+    int plen, maxplen = 0;
 
     for (;;) {
 	for (; *y; y += ((unsigned char)*y & 0x80) ? 2 : 1) {
@@ -370,8 +355,7 @@ static void set_ruby(dest, midasi, yomi, par1, par2, par3)
     *d = '\0';
 }
 
-static void print_nhinsi(hinsi, c, n)
-    int hinsi, c, n;
+static void print_nhinsi(int hinsi, int c, int n)
 {
     short *path;
     int i;
@@ -398,8 +382,7 @@ static void print_nhinsi(hinsi, c, n)
  * int_to_str - convert an integer to ASCII
  *	by Masanao Izumo <masana-i@is.aist-nara.ac.jp>
  ***********************************************************************/
-static char *int_to_str(value)
-    int value;
+static char *int_to_str(int value)
 {
     static char buff[32];
     char* p;
@@ -431,10 +414,7 @@ static char *int_to_str(value)
  * fputsn
  *	by Masanao Izumo <masana-i@is.aist-nara.ac.jp>
  ***********************************************************************/
-static void fputsn(str, fp, n)
-    char *str;
-    FILE* fp;
-    int n;
+static void fputsn(char *str, char *out, int n)
 {
     char buff[256];
     int len;
@@ -443,7 +423,7 @@ static void fputsn(str, fp, n)
 	len = (n <= 255 ? n : 255);
 	memcpy(buff, str, len);
 	buff[len] = '\0';
-	cha_puts(buff, fp);
+	cha_puts(buff, out);
 	str += len;
 	n -= len;
     }
@@ -453,8 +433,7 @@ static void fputsn(str, fp, n)
  * printf_field
  *	by Masanao Izumo <masana-i@is.aist-nara.ac.jp>
  ***********************************************************************/
-static void printf_field(width_str, word)
-    char *width_str, *word;
+static void printf_field(char *width_str, char *word)
 {
     char *field = width_str;
     int field_len, word_len;
@@ -514,8 +493,7 @@ static void printf_field(width_str, word)
     }
 }
 
-static int get_deli_right(c)
-    int c;
+static int get_deli_right(int c)
 {
     switch (c) {
       case '(': return ')';
@@ -526,9 +504,7 @@ static int get_deli_right(c)
     }
 }
 
-static void print_anno(path_num, format)
-    int path_num;
-    char *format;
+static void print_anno(int path_num, char *format)
 {
     path_t *path = &Cha_path[path_num];
     mrph2_t mrph;
@@ -578,8 +554,7 @@ static void print_anno(path_num, format)
     path->start = start;
 }
 
-static void extract_yomi1(dst, src)
-    char *dst, *src;
+static void extract_yomi1(char *dst, char *src)
 {
     int in_brace = 0, is1st = 0;
     char *s, *d;
@@ -609,13 +584,10 @@ static void extract_yomi1(dst, src)
     *d = '\0';
 }
 
-void cha_printf_mrph(path_num, mrph, format)
-    int path_num;
-    mrph2_t *mrph;
-    char *format;
+void cha_printf_mrph(int path_num, mrph2_t *mrph, char *format)
 {
     int  letter, value, n, state;
-    int  deli_left, deli_right;
+    int  deli_left = 0, deli_right = 0;
     char *s, *word, *eword;
     char word_str[CHA_INPUT_SIZE], word_str2[CHA_INPUT_SIZE];
     char *width_str;
@@ -816,7 +788,11 @@ void cha_printf_mrph(path_num, mrph, format)
 	      s++;
 	    break;
 	  case 'i': /* ղþ */
-	    eword = mrph->info;
+	    if (s[1] != '0')
+	      extract_yomi1(word_str, mrph->info);
+	    else
+	      strcpy(word_str, mrph->info);
+	    eword = word_str;
 	    break;
 	  case 'I': /* ղþ */
 	    if (*++s == '\0')
@@ -951,15 +927,10 @@ void cha_printf_mrph(path_num, mrph, format)
 	    printf_field(width_str, word);
 	    word = NULL;
 	} else if (eword != NULL) {
-#if defined(KOCHA2) || defined(SJIS)
+#ifdef SJIS
 	    char tmp_str[CHA_INPUT_SIZE];
 	    strcpy(tmp_str, eword);
-#ifdef KOCHA2
-	    jaso2ks(tmp_str);
-#endif
-#ifdef SJIS
 	    euc2sjis(tmp_str);
-#endif
 	    eword = tmp_str;
 #endif
 	    printf_field(width_str, eword);
@@ -983,8 +954,7 @@ void cha_printf_mrph(path_num, mrph, format)
 #endif
 }
 
-static void print_bos_eos(str)
-    char *str;
+static void print_bos_eos(char *str)
 {
     char *s;
 
@@ -996,15 +966,13 @@ static void print_bos_eos(str)
     }
 }	      
 
-static void print_bos(opt_form)
-    int opt_form;
+static void print_bos(int opt_form)
 {
     if (opt_form != 'W' && opt_form != 'd' && *Cha_bos_string)
       print_bos_eos(Cha_bos_string);
 }
 
-static void print_eos(opt_form)
-    int opt_form;
+static void print_eos(int opt_form)
 {
     if (opt_form == 'W')
       cha_putc('\n', cha_output);
@@ -1015,10 +983,7 @@ static void print_eos(opt_form)
 /*
  * print_path_mrph
  */
-static void print_mrph(path_num, mrph, format)
-    int path_num;
-    mrph2_t *mrph;
-    char *format;
+static void print_mrph(int path_num, mrph2_t *mrph, char *format)
 {
     print_anno(path_num, format);
     if (Cha_output_compo || *mrph->comp == '\n')
@@ -1041,25 +1006,18 @@ static void print_mrph(path_num, mrph, format)
     }
 }
 
-static void print_path_mrph(path_num, format)
-    int path_num;
-    char *format;
+static void print_path_mrph(int path_num, char *format)
 {
-#ifdef KOCHA_DEBUG
-    printf("%4d: ", Cha_path[path_num].mrph_p);
-#endif
     print_mrph(path_num, &Cha_mrph[Cha_path[path_num].mrph_p], format);
 }
 
 /*
  * print_best_path()
  */
-static void print_best_path(opt_form, format)
-    int opt_form;
-    char *format;
+static void print_best_path(int opt_form, char *format)
 {
     int i, last, pbuf_last, isfirst = 1;
-    int path_num_comp;
+    int path_num_comp = 0;
     char yomi[CHA_INPUT_SIZE];
     char pron[CHA_INPUT_SIZE];
     char base[CHA_INPUT_SIZE];
@@ -1172,8 +1130,7 @@ static void print_best_path(opt_form, format)
  * print_all_mrph - Ϸ̤˴ޤޤƤηǤɽ
  *	-m, -d, -v ץǻ
  */
-static void collect_all_mrph(path_num)
-    int path_num;
+static void collect_all_mrph(int path_num)
 {
     int i, j;
 
@@ -1188,9 +1145,7 @@ static void collect_all_mrph(path_num)
     }
 }
 
-static void print_all_mrph(opt_form, format)
-    int opt_form;
-    char *format;
+static void print_all_mrph(int opt_form, char *format)
 {
     int i;
     int isfirst = 1; /* ʸƬɤΥե饰 for -d option */
@@ -1224,9 +1179,7 @@ static void print_all_mrph(opt_form, format)
 /*
  * print_all_path()
  */
-static void print_all_path_sub(path_num, paths, opt_form, format)
-    int path_num, paths, opt_form;
-    char *format;
+static void print_all_path_sub(int path_num, int paths, int opt_form, char *format)
 {
     int i, j;
 
@@ -1245,18 +1198,14 @@ static void print_all_path_sub(path_num, paths, opt_form, format)
     }
 }
 
-static void print_all_path(opt_form, format)
-    int opt_form;
-    char *format;
+static void print_all_path(int opt_form, char *format)
 {
     print_bos(opt_form);
     print_all_path_sub(Cha_path_num - 1, 0, opt_form, format);
-    print_eos(opt_form, format);
+    print_eos(opt_form);
 }
 
-void cha_print_path(opt_show, opt_form, format)
-    int opt_show, opt_form;
-    char *format;
+void cha_print_path(int opt_show, int opt_form, char *format)
 {
     if (opt_form == 'd')
       cha_putc('[', cha_output);
@@ -1271,15 +1220,14 @@ void cha_print_path(opt_show, opt_form, format)
       cha_puts("].\n", cha_output);
 }
 
-void cha_print_bos_eos(opt_form)
-    int opt_form;
+void cha_print_bos_eos(int opt_form)
 {
     cha_set_sentence("", NULL, NULL);
     print_bos(opt_form);
     print_eos(opt_form);
 }
 
-void cha_print_hinsi_table()
+void cha_print_hinsi_table(void)
 {
     int i;
 
@@ -1290,18 +1238,17 @@ void cha_print_hinsi_table()
     }
 }
 
-void cha_print_ctype_table()
+void cha_print_ctype_table(void)
 {
     int i;
     for (i = 1; Cha_type[i].name; i++)
       cha_printf(cha_output, "%d %s\n", i, Cha_type[i].name);
 }
 
-void cha_print_cform_table()
+void cha_print_cform_table(void)
 {
     int i, j;
     for (i = 1; Cha_type[i].name; i++)
       for (j = 1; Cha_form[i][j].name; j++)
 	printf("%d %d %s\n", i, j, Cha_form[i][j].name);
 }
-
