@@ -1,9 +1,9 @@
-/*-
- *                                                 
- * select.c - ¹Ԥ                      
- * SUFARY --- Suffix Array ΤΥ饤֥  
+/*
+ * select.c - search with suffix array file
  *
- * Copyright (c) 1996, 1997, 2000 Nara Institute of Science and Technology
+ * Copyright (C) 2000, 2001, 
+ *                            Nara Institute of Science and Technology
+ *                           
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -35,7 +35,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: select.c,v 1.6.4.1 2000/12/18 20:08:31 masayu-a Exp $
+ * $Id: select.c,v 1.12 2001/02/23 13:07:14 kazuma-t Exp $
  */
 
 #include <stdio.h>
@@ -46,11 +46,11 @@
 #define MINMIN(X,Y) ((X) < (Y) ? (X) : (Y))
 
 /* sistring  */
-static int cmp_sistr();
-static eresult sa_search();
+static int cmp_sistr(char*, char*, int*, int);
+static eresult sa_search(SUFARY*, char*, int, int);
 
 #define sa_aryidx2txtptr(ary, idx) \
-(ary->txtmap + ntohl(((long *)(ary->arymap + idx * sizeof(long)))[0]))
+((ary)->txtmap + ntohl(((long *)((ary)->arymap + (idx) * sizeof(long)))[0]))
 
 
 /******************************************************************************
@@ -88,10 +88,7 @@ static eresult sa_search();
  *       ary->right, ary->left : ưŪ˼θϰϤ򶹤
  *
  *****************************************************************************/
-static eresult sa_search(ary, s, keylen, base_offset)
-    SUFARY *ary;
-    char *s;
-    int keylen, base_offset;
+static eresult sa_search(SUFARY *ary, char *s, int keylen, int base_offset)
 {
     long left_outside, right_outside, left_inside, right_inside, cur, tmp;
     int hr;
@@ -208,9 +205,7 @@ static eresult sa_search(ary, s, keylen, base_offset)
  *   980422 ¤
  *
  *****************************************************************************/
-static int cmp_sistr(txt, str, diffpos, len)
-    char *txt, *str;
-    int *diffpos, len;
+static int cmp_sistr(char *txt, char *str, int *diffpos, int len)
 {
     int i;
     for (i = 0; i < len; i++, txt++, str++)
@@ -241,8 +236,14 @@ static int cmp_sistr(txt, str, diffpos, len)
     { (ary)->left = 0; \
       (ary)->right = (ary)->arraysize - 1; }
 
+extern int Cha_lang_e;
+#define mbclen(mb) \
+((!Cha_lang_e && ((unsigned char)(mb) & 0x80)) ? 2 : 1)
+
 /******************************************************************************
- *   char **sa_common_prefix_search(SUFARY *ary, char *pattern,
+ *   char **sa_common_prefix_search(SUFARY *ary,
+ *                                  char *pattern,
+ *                                  char* char_tyep,
  *                                  char **result);
  *
  * purpose
@@ -251,6 +252,7 @@ static int cmp_sistr(txt, str, diffpos, len)
  * parameters
  *   ary : оarray
  *   pattern : 
+ *   char_type : pattern ư֤ʸΥХĹ
  *   result  : ̤ǼХåե
  *
  * return value
@@ -265,15 +267,7 @@ static int cmp_sistr(txt, str, diffpos, len)
  * 
  * since 1998/04/09
  *****************************************************************************/
-extern int Cha_lang_e;
-
-#define mbclen(mb) \
-((!Cha_lang_e && ((unsigned char)mb & 0x80)) ? 2 : 1)
-
-char **sa_common_prefix_search(ary, pattern, result)
-    SUFARY *ary;
-    char *pattern;
-    char **result;
+char **sa_common_prefix_search(SUFARY *ary, char *pattern, char *char_type, char **result)
 {
     int cursor;
     int result_last = 0;
