@@ -10,12 +10,12 @@
 #include "chadic.h"
 
 /* trans.c */
-extern void trans();
+extern void trans(FILE*, FILE*);
 
 /*
  * usage()
  */
-static void usage()
+static void usage(void)
 {
     fprintf(stderr, "usage: makeint [ -q ] [ -o outfile ] dicfile...\n");
     exit(1);
@@ -24,9 +24,7 @@ static void usage()
 /*
  * translate()
  */
-static void translate(dicfile, fp_out, fp_w)
-    char *dicfile;
-    FILE *fp_out, *fp_w;
+static void translate(char *dicfile, FILE *fp_out, FILE *fp_w)
 {
     FILE *fp_in;
 
@@ -40,9 +38,7 @@ static void translate(dicfile, fp_out, fp_w)
 /*
  * mainproc()
  */
-static void mainproc(argv, fp_out, fp_w)
-    char *argv[];
-    FILE *fp_out, *fp_w;
+static void mainproc(char *argv[], FILE *fp_out, FILE *fp_w)
 {
     time_t t0, t1;
 #if defined _WIN32 && ! defined __CYGWIN__
@@ -76,9 +72,7 @@ static void mainproc(argv, fp_out, fp_w)
 /*
  * main()
  */
-int main(argc, argv)
-    int argc;
-    char *argv[];
+int main(int argc, char *argv[])
 {
     FILE *fp_out, *fp_w;
     int c;
@@ -112,4 +106,3 @@ int main(argc, argv)
 
     return 0;
 }
-
