@@ -41,16 +41,12 @@ static int            j_num;
 
 static connect_rule_t **connect_mtr1;
 static connect_rule_t **connect_mtr2;
-#ifdef KOCHA
-typedef unsigned short rensetu_mtr_t;
-#else
 typedef unsigned char  rensetu_mtr_t;
-#endif
 
 /***********************************************************************
  * read_kankei - read chasen's kankei file
  ***********************************************************************/
-static void read_kankei()
+static void read_kankei(void)
 {
     FILE *fp;
     chasen_cell_t *cell1, *cell2;
@@ -86,9 +82,7 @@ static void read_kankei()
 /***********************************************************************
  * get_pair1
  ***********************************************************************/
-static void get_pair1(cell, pair)
-    chasen_cell_t *cell;
-    rensetu_pair_t *pair;
+static void get_pair1(chasen_cell_t *cell, rensetu_pair_t *pair)
 {
     chasen_cell_t *cell_p;
 
@@ -117,9 +111,7 @@ static void get_pair1(cell, pair)
 /***********************************************************************
  * get_pair2
  ***********************************************************************/
-static void get_pair2(cell, pair)
-    chasen_cell_t *cell;
-    rensetu_pair2_t *pair;
+static void get_pair2(chasen_cell_t *cell, rensetu_pair2_t *pair)
 {
     chasen_cell_t *cell_p;
     char *s;
@@ -158,8 +150,7 @@ static void get_pair2(cell, pair)
 /***********************************************************************
  * match_pair1
  ***********************************************************************/
-static int match_pair1(pair1, pair2)
-    rensetu_pair_t *pair1, *pair2;
+static int match_pair1(rensetu_pair_t *pair1, rensetu_pair_t *pair2)
 {
     if (pair1->hinsi == pair2->hinsi &&
 	pair1->type == pair2->type &&
@@ -173,9 +164,7 @@ static int match_pair1(pair1, pair2)
 /***********************************************************************
  * match_pair2
  ***********************************************************************/
-static int match_pair2(pair, tbl)
-    rensetu_pair2_t *pair;
-    rensetu_pair_t *tbl;
+static int match_pair2(rensetu_pair2_t *pair, rensetu_pair_t *tbl)
 {
     /* ʸƬ, ʸ */
     if (pair->hinsi == NULL)
@@ -194,9 +183,7 @@ static int match_pair2(pair, tbl)
 /***********************************************************************
  * make_rensetu_tbl1 - register hinsi with goi
  ***********************************************************************/
-void make_rensetu_tbl1(cell1, cnt)
-    chasen_cell_t *cell1;
-    int *cnt;
+void make_rensetu_tbl1(chasen_cell_t *cell1, int *cnt)
 {
     int i;
     rensetu_pair_t r_pair;
@@ -237,8 +224,7 @@ void make_rensetu_tbl1(cell1, cnt)
 /***********************************************************************
  * make_rensetu_tbl2 - register hinsi
  ***********************************************************************/
-static void make_rensetu_tbl2(hinsi, bunrui, cnt)
-    int hinsi, bunrui, *cnt;
+static void make_rensetu_tbl2(int hinsi, int bunrui, int *cnt)
 {
     int i, j;
 
@@ -257,19 +243,6 @@ static void make_rensetu_tbl2(hinsi, bunrui, cnt)
 		}
 	    }
 	}
-#ifdef KOCHA2
-    } else if (Cha_hinsi[hinsi].kt == 2) {
-	extern char *Gomatsu[];
-	for (i = 0; Gomatsu[i]; i++, (*cnt)++) {
-	    rensetu_tbl[*cnt].hinsi  = hinsi;
-	    rensetu_tbl[*cnt].type   = cha_get_type_id(Gomatsu[i]);
-	    rensetu_tbl[*cnt].form   = 0;
-	    rensetu_tbl[*cnt].goi    = NULL;
-	}
-	if (*cnt >= REN_TBL_MAX) 
-	    cha_exit(1, "not enough size for table");
-#endif
-
     } else {
 	/* Ѥʤ */
 	rensetu_tbl[*cnt].hinsi  = hinsi;
@@ -285,8 +258,7 @@ static void make_rensetu_tbl2(hinsi, bunrui, cnt)
 /***********************************************************************
  * make_rensetu_tbl - register hinsi into table
  ***********************************************************************/
-static int make_rensetu_tbl(fp)
-    FILE *fp;
+static int make_rensetu_tbl(FILE *fp)
 {
     chasen_cell_t *cell;
     int i, lines;
@@ -319,8 +291,7 @@ static int cell_num;
 static int new_cell1[RENSETU_CELL_MAX], new_cell2[RENSETU_CELL_MAX];
 static int new_cell1_num, new_cell2_num;
 
-static int search_rensetu_cell(tbl, prev)
-    int tbl, prev;
+static int search_rensetu_cell(int tbl, int prev)
 {
     int i;
 
@@ -338,8 +309,7 @@ static int search_rensetu_cell(tbl, prev)
 }
 
 /* c2  c1  suffix ɤ */
-static int match_rensetu_cell_suffix(c1, c2)
-    int c1, c2;
+static int match_rensetu_cell_suffix(int c1, int c2)
 {
     int n;
 
@@ -353,8 +323,7 @@ static int match_rensetu_cell_suffix(c1, c2)
     return n;
 }
 
-static void match_rensetu_cell_tbl(tbl, cells)
-    int tbl, *cells;
+static void match_rensetu_cell_tbl(int tbl, int *cells)
 {
     int *c, i;
 
@@ -369,8 +338,7 @@ static void match_rensetu_cell_tbl(tbl, cells)
 /***********************************************************************
  * add_connect_rule
  ***********************************************************************/
-static void add_connect_rule(in, prev, cost, is_last, in_cells, cur_cells)
-    int in, prev, cost, is_last, *in_cells, *cur_cells;
+static void add_connect_rule(int in, int prev, int cost, int is_last, int *in_cells, int *cur_cells)
 {
     int cur, next, *curp, *cellp;
     int suffix_len, suffix_len_max;
@@ -413,9 +381,7 @@ static void add_connect_rule(in, prev, cost, is_last, in_cells, cur_cells)
 /***********************************************************************
  * read_rensetu
  ***********************************************************************/
-static void read_rensetu(fp, lines)
-    FILE *fp;
-    int lines;
+static void read_rensetu(FILE *fp, int lines)
 {
     chasen_cell_t **rule;
     int *rule_len;
@@ -594,8 +560,7 @@ static void read_rensetu(fp, lines)
     }
 }
 
-static int compare_vector1(k, j, num)
-    int k, j, num;
+static int compare_vector1(int k, int j, int num)
 {
     int i;
      
@@ -607,8 +572,7 @@ static int compare_vector1(k, j, num)
     return 1;
 }
 
-static void copy_vector1(j, j_n, num)
-    int j, j_n, num;
+static void copy_vector1(int j, int j_n, int num)
 {
     int i;
 
@@ -618,8 +582,7 @@ static void copy_vector1(j, j_n, num)
     }
 }
 
-static int compare_vector2(k, i, num)
-    int k, i, num;
+static int compare_vector2(int k, int i, int num)
 {
     int j;
 
@@ -631,8 +594,7 @@ static int compare_vector2(k, i, num)
     return 1;
 }
 
-static void copy_vector2(i, i_n, num)
-    int i, i_n, num;
+static void copy_vector2(int i, int i_n, int num)
 {
     int j;
 
@@ -645,7 +607,7 @@ static void copy_vector2(i, i_n, num)
 /***********************************************************************
  * condense_matrix
  ***********************************************************************/
-static void condense_matrix()
+static void condense_matrix(void)
 {
     int i, j, k;
     int i_n = 0;
@@ -694,7 +656,7 @@ static void condense_matrix()
 /***********************************************************************
  * write_table, write_matrix
  ***********************************************************************/
-static void write_table()
+static void write_table(void)
 {
     FILE *fp;
     rensetu_pair_t *tbl;
@@ -722,7 +684,7 @@ static void write_table()
     fclose(fp);
 }
 
-static void write_matrix()
+static void write_matrix(void)
 {
     FILE *fp;
     int i, j;
@@ -766,9 +728,7 @@ static void write_matrix()
 /***********************************************************************
  * main
  ***********************************************************************/
-int main(argc, argv)
-    int argc;
-    char **argv;
+int main(int argc, char *argv[])
 {
     FILE *fpc;
     int lines;
