@@ -5,6 +5,13 @@ suffix array ץ
 NLPRS '95  Invited Lecture  Kenneth W. Church
 ΤΤѤޤ
 */
+#include "config.h"
+#if defined _WIN32 && ! defined __CYGWIN__
+#include <io.h>
+#include <process.h>
+#else
+#include <unistd.h>
+#endif /* _WIN32 && ! defined __CYGWIN__ */
 #include <fcntl.h>
 #include <stdio.h>
 #include <string.h>
@@ -24,11 +31,11 @@ typedef unsigned char *caddr_t;
 #define MODE_ON 1
 #define MODE_OFF 0
 
-void open_array_file();
-size_t open_text_file();
-void sort_array_file();
-long make_first_array_file();
-void usage();
+void open_array_file(char*);
+size_t open_text_file(char*);
+void sort_array_file(char*, long);
+long make_first_array_file(long);
+void usage(void);
 
 /*=============
    ѿ
@@ -50,8 +57,7 @@ FILE *ofd = NULL; /* ե */
 
 
 
-int suffix_compare(a, b)
-    long *a, *b;
+int suffix_compare(long *a, long *b)
 {
     long ha, hb;
 
@@ -67,14 +73,12 @@ int suffix_compare(a, b)
 */
 }
 
-int main(argc, argv)
-    int argc;
-    char **argv;
+int main(int argc, char *argv[])
 {
   char in_fname[FNLEN]; /* ϥե̾ */
   char ary_fname[FNLEN]; /* ե̾ */
   size_t N;
-  long pointer_cnt;
+  long pointer_cnt = 0;
 
   in_fname[0] = '\0';
   ary_fname[0] = '\0';
@@ -170,8 +174,7 @@ int main(argc, argv)
 /******************************************************************************
   ƥȥե򳫤
  *****************************************************************************/
-size_t open_text_file(fname)
-    char *fname;
+size_t open_text_file(char *fname)
 {
   struct stat stat_buf;
   int fd;
@@ -202,8 +205,7 @@ size_t open_text_file(fname)
 /******************************************************************************
   arrayե򳫤
  *****************************************************************************/
-void open_array_file(fname)
-    char *fname;
+void open_array_file(char *fname)
 {
   if((ofd = fopen(fname,"w")) == NULL){
     fprintf(stderr,"ե \"%s\" ץޤ\n", fname);
@@ -229,8 +231,7 @@ void open_array_file(fname)
  *   ݥ󥿤򿶤ؿ(㤨СʸȤƬʤ)ϡ
  *   option_byline, delimitter ʤɤѿǷ롣
  *****************************************************************************/
-long make_first_array_file(N)
-    long N;
+long make_first_array_file(long N)
 {
   long i, jj = 0, index;
   int last_char_is_delimitter = 1;
@@ -319,9 +320,7 @@ long make_first_array_file(N)
 /******************************************************************************
   ݥ󥿤򥽡
  *****************************************************************************/
-void sort_array_file(ary_fname, pointer_cnt)
-    char *ary_fname;
-    long pointer_cnt;
+void sort_array_file(char *ary_fname, long pointer_cnt)
 {
   struct stat om_stat_buf;
   char *outmap;
@@ -362,7 +361,7 @@ void sort_array_file(ary_fname, pointer_cnt)
 /*
    usage --- Ȥ
 */
-void usage(){
+void usage(void){
     static char *message[] = {
 	"\n",
 	"Version 1.4 980602 (SUFARY Version 2.0)\n\n",
