@@ -12,9 +12,11 @@
 #include "chadic.h"
 
 #define LINEMAX 8192
+#define DEFAULT_NLINE (1024 * 256)
 
 typedef struct _line_info {
     long ptr;
+    long len;
     char *midasi;
 } line_info;
 
@@ -24,8 +26,7 @@ static char *buffer_ptr[BLOCK_MAX];
 static int  buffer_ptr_num = 0;
 static int  buffer_idx = BLOCK_SIZE;
 
-static char *cha_malloc_char(size)
-    int size;
+static char *cha_malloc_char(int size)
 {
     if (buffer_idx + size >= BLOCK_SIZE) {
 	if (buffer_ptr_num == BLOCK_MAX)
@@ -38,132 +39,136 @@ static char *cha_malloc_char(size)
     return buffer_ptr[buffer_ptr_num - 1] + buffer_idx - size;
 }
 
-static int ustrcmp(s1, s2)
-    unsigned char *s1, *s2;
+static int ustrcmp(unsigned char *s1, unsigned char *s2)
 {
     for (; *s1 && *s1 == *s2; s1++, s2++);
     return (int)(*s1 - *s2);
 }
 
-static int midasi_compare(l1, l2)
-    line_info *l1, *l2;
+static int midasi_compare(line_info *l1, line_info *l2)
 {
-#if 0
-    return ustrcmp(l1->midasi, l2->midasi) || (int)(l1->ptr - l2->ptr);
-#else
     int rc;
+
     rc = ustrcmp(l1->midasi, l2->midasi);
     if (rc)
       return rc;
     else
       return (int)(l1->ptr - l2->ptr);
-#endif
 }
 
-static void sortdic(infile, outfile)
-    char *infile, *outfile;
+static void normal_sort(FILE *fpi, FILE *fpo, char *filebuf)
+{
+    line_info *line;
+    long nline, l;
+    long n_line_info = DEFAULT_NLINE;
+    char *bol, *b, *pre = "";
+    long len;
+    int c;
+
+    line = cha_malloc(sizeof(line_info) * n_line_info);
+
+    fprintf(stderr, "reading... ");
+
+    nline = 0;
+    bol = filebuf;
+    while ((c = fgetc(fpi)) != EOF) {
+	*filebuf = c;
+	filebuf++;
+        if (c == '\n') {
+	    if (nline >= n_line_info) {
+		n_line_info *= 2;
+		line = cha_realloc(line, n_line_info);
+	    }
+	    line[nline].midasi = bol;
+	    line[nline].ptr = nline;
+	    line[nline].len = filebuf - bol;
+	    nline++;
+	    bol = filebuf;
+	}
+    }
+    fprintf(stderr, "(%ld lines) ", nline);
+
+    fprintf(stderr, "sorting... ");
+    qsort(line, nline, sizeof(line_info), (int (*)())midasi_compare);
+
+    fprintf(stderr, "writing... ");
+
+    for (l = 0; l < nline; l++) {
+	b = line[l].midasi;
+	len = line[l].len;
+	if (memcmp(pre, b, len) != 0) { /* uniq */
+	    fwrite(b, len, 1, fpo);
+	    pre = b;
+	}
+    }
+}
+
+static void nomem_sort(FILE *fpi, FILE *fpo)
+{
+    line_info *line;
+    int nline, l;
+    char buf[LINEMAX];
+    char prebuf[LINEMAX];
+    int len;
+
+    fprintf(stderr, "counting lines... ");
+    for (nline = 0; fgets(buf, sizeof(buf), fpi) != NULL; nline++)
+	;
+    fprintf(stderr, "(%d lines) ", nline);
+    line = (line_info *)cha_malloc(sizeof(line_info) * nline);
+
+    fprintf(stderr, "reading... ");
+    rewind(fpi);
+    for (l = 0; l < nline; l++) {
+	line[l].ptr = ftell(fpi);
+	fgets(buf, sizeof(buf), fpi);
+	line[l].midasi = cha_malloc_char(strlen(buf) + 1);
+	strcpy(line[l].midasi, buf);
+    }
+
+    fprintf(stderr, "sorting... ");
+    qsort(line, nline, sizeof(line_info), (int (*)())midasi_compare);
+
+    fprintf(stderr, "writing... ");
+
+    prebuf[0] = '\0';
+    for (l = 0; l < nline; l++) {
+	fseek(fpi, line[l].ptr, SEEK_SET);
+	fgets(buf, sizeof(buf), fpi);
+	len = (char *)memchr(buf, '\n', sizeof(buf)) + 1 - buf;
+	if (memcmp(prebuf, buf, len)) {
+	    fwrite(buf, len, 1, fpo);
+	    memcpy(prebuf, buf, len);
+	}
+    }
+}
+
+static void sortdic(char *infile, char *outfile)
 {
     FILE *fpi, *fpo;
     struct stat st;
-    line_info *line;
-    int nline, l;
-    char buf[LINEMAX], *filebuf, *fb;
+    char *filebuf;
 
     fpi = cha_fopen(infile, "r", 1);
     /* eol is "\n" for UNIX/Win */
     fpo = outfile ? cha_fopen(outfile, "wb", 1) : stdout;
 
     fstat(fileno(fpi), &st);
+    filebuf = malloc(st.st_size);
 
-#if 1
-    fb = filebuf = malloc(st.st_size);
-#else
-    fb = filebuf = NULL;
-#endif
     if (filebuf != NULL) {
-#if 1
-	fprintf(stderr, "reading... ");
-#endif
-	/* note: sizeof(buf) is CORRECT */
-	for (nline = 0; fgets(fb, sizeof(buf), fpi) != NULL; nline++)
-	  fb = (char *)memchr(fb, '\n', sizeof(buf)) + 1;
+	normal_sort(fpi, fpo, filebuf);
     } else {
-	/* cannot malloc */
-#if 1
-	fprintf(stderr, "counting lines... ");
-#endif
-	for (nline = 0; fgets(buf, sizeof(buf), fpi) != NULL; nline++);
+	nomem_sort(fpi, fpo);
     }
 
-#if 1
-    fprintf(stderr, "(%d lines) ", nline);
-#endif
-    line = (line_info *)cha_malloc(sizeof(line_info) * nline);
-
-    if (filebuf) {
-	fb = filebuf;
-	for (l = 0; l < nline; l++) {
-	    line[l].midasi = fb;
-	    line[l].ptr = l;
-	    fb = (char *)memchr(fb, '\n', sizeof(buf)) + 1;
-	}
-    } else {
-	/* cannot malloc */
-#if 1
-	fprintf(stderr, "reading... ");
-#endif
-	rewind(fpi);
-	for (l = 0; l < nline; l++) {
-	    line[l].ptr = ftell(fpi);
-	    fgets(buf, sizeof(buf), fpi);
-	    line[l].midasi = cha_malloc_char(strlen(buf) + 1);
-	    strcpy(line[l].midasi, buf);
-	}
-    }
-
-#if 1
-    fprintf(stderr, "sorting... ");
-#endif
-    qsort(line, nline, sizeof(line_info), (int (*)())midasi_compare);
-
-#if 1
-    fprintf(stderr, "writing... ");
-#endif
-
-    if (filebuf) {
-	char *b, *pre = "";
-	int len;
-	for (l = 0; l < nline; l++) {
-	    b = line[l].midasi;
-	    len = (char *)memchr(b, '\n', sizeof(buf)) + 1 - b;
-	    if (memcmp(pre, b, len)) {
-		fwrite(b, len, 1, fpo);
-		pre = b;
-	    }
-	}
-    } else {
-	char prebuf[LINEMAX];
-	int len;
-	prebuf[0] = '\0';
-	for (l = 0; l < nline; l++) {
-	    fseek(fpi, line[l].ptr, SEEK_SET);
-	    fgets(buf, sizeof(buf), fpi);
-	    len = (char *)memchr(buf, '\n', sizeof(buf)) + 1 - buf;
-	    if (memcmp(prebuf, buf, len)) {
-		fwrite(buf, len, 1, fpo);
-		memcpy(prebuf, buf, len);
-	    }
-	}
-    }
     fclose(fpi);
     fclose(fpo);
 
     fprintf(stderr, "done.\n");
 }
 
-int main(argc, argv)
-    int argc;
-    char *argv[];
+int main(int argc, char *argv[])
 {
     time_t t0, t1;
 
