@@ -12,8 +12,7 @@
 /*
  * strcmp_tail
  */
-static int strcmp_tail(s1, s2)
-    char *s1, *s2;
+static int strcmp_tail(char *s1, char *s2)
 {
     int diff_len;
 
@@ -28,9 +27,7 @@ static int strcmp_tail(s1, s2)
 /*
  * print_mrph
  */
-static void print_mrph1(fp, mrph)
-    FILE *fp;
-    mrph_t *mrph;
+static void print_mrph1(FILE *fp, mrph_t *mrph)
 {
     fprintf(fp, "%s%c%s%c%s%c%s%c%s%c%c%c%c%c%c%c%c%c",
 	    mrph->midasi, 0, mrph->yomi, 0, mrph->pron, 0,
@@ -44,27 +41,21 @@ static void print_mrph1(fp, mrph)
 	    mrph->con_tbl % CHAINT_SCALE + CHAINT_OFFSET);
 }
 
-static void print_mrph_comp(fp, mrph)
-    FILE *fp;
-    mrph_t *mrph;
+static void print_mrph_comp(FILE *fp, mrph_t *mrph)
 {
     for (; mrph->hinsi; mrph++) 
       print_mrph1(fp, mrph);
     fputc('\n', fp);
 }
 
-static void print_mrph_with_midasi(fp, mrph)
-    FILE *fp;
-    mrph_t *mrph;
+static void print_mrph_with_midasi(FILE *fp, mrph_t *mrph)
 {
     print_mrph1(fp, mrph);
     print_mrph_comp(fp, mrph + 1);
 }
 
 /* ФΤʤñϤ٤Ƥγѷ */
-static void print_mrph_without_midasi(fp, mrph)
-    FILE *fp;
-    mrph_t *mrph;
+static void print_mrph_without_midasi(FILE *fp, mrph_t *mrph)
 {
     int i;
 
@@ -87,9 +78,7 @@ static void print_mrph_without_midasi(fp, mrph)
     }
 }
 
-static void print_mrph(fp, mrph)
-    FILE *fp;
-    mrph_t *mrph;
+static void print_mrph(FILE *fp, mrph_t *mrph)
 {
     if (mrph->midasi[0])
       print_mrph_with_midasi(fp, mrph);
@@ -100,9 +89,7 @@ static void print_mrph(fp, mrph)
 /*
  * trans_exit
  */
-static void trans_exit(status, msg, cell)
-    char *msg;
-    chasen_cell_t *cell;
+static void trans_exit(int status, char *msg, chasen_cell_t *cell)
 {
     cha_exit_file(status, "`%s' %s\n", cha_s_tostr(cell), msg);
 }
@@ -110,8 +97,7 @@ static void trans_exit(status, msg, cell)
 /*
  * get_midasi_list
  */
-static chasen_cell_t *get_midasi_list(x)
-    chasen_cell_t *x;
+static chasen_cell_t *get_midasi_list(chasen_cell_t *x)
 {
     chasen_cell_t *y;
 
@@ -125,14 +111,11 @@ static chasen_cell_t *get_midasi_list(x)
 /*
  * get_midasi_str_weight
  */
-static void get_midasi_str_weight(cell, def_weight, mrph)
-    chasen_cell_t *cell;
-    int def_weight;
-    mrph_t *mrph;
+static void get_midasi_str_weight(chasen_cell_t *cell, int def_weight, mrph_t *mrph)
 {
     double weight_double;
     int weight_int;
-    char *midasi_str;
+    char *midasi_str = NULL;
 
     if (atomp(cell)) {
 	/* (Ф ߡߡ ...) */
@@ -181,8 +164,7 @@ static void get_midasi_str_weight(cell, def_weight, mrph)
 /*
  * get_yomi
  */
-static char *get_yomi(x)
-    chasen_cell_t *x;
+static char *get_yomi(chasen_cell_t *x)
 {
     chasen_cell_t *y;
     char *s;
@@ -202,8 +184,7 @@ static char *get_yomi(x)
     return s;
 }
 
-static int get_hinsi(x)
-    chasen_cell_t *x;
+static int get_hinsi(chasen_cell_t *x)
 {
     chasen_cell_t *y;
 
@@ -217,8 +198,7 @@ static int get_hinsi(x)
 /*
  * get_ktype
  */
-static int get_ktype(x)
-    chasen_cell_t *x;
+static int get_ktype(chasen_cell_t *x)
 {
     chasen_cell_t *y;
 
@@ -232,9 +212,7 @@ static int get_ktype(x)
 /*
  * get_ktype
  */
-static int get_kform(x, ktype)
-    chasen_cell_t *x;
-    int ktype;
+static int get_kform(chasen_cell_t *x, int ktype)
 {
     chasen_cell_t *y;
 
@@ -249,8 +227,7 @@ static int get_kform(x, ktype)
 /*
  * get_edrconnect
 */
-static chasen_cell_t *get_edrconnect(x)
-    chasen_cell_t *x;
+static chasen_cell_t *get_edrconnect(chasen_cell_t *x)
 {
     chasen_cell_t *y;
 
@@ -261,8 +238,7 @@ static chasen_cell_t *get_edrconnect(x)
 /*
  * get_info
  */
-static char *get_info(x)
-    chasen_cell_t *x;
+static char *get_info(chasen_cell_t *x)
 {
     chasen_cell_t *y;
 
@@ -275,8 +251,7 @@ static char *get_info(x)
     return cha_s_atom(cha_car(cha_cdr(y)));
 }
 
-static char *get_base(x)
-    chasen_cell_t *x;
+static char *get_base(chasen_cell_t *x)
 {
     chasen_cell_t *y;
 
@@ -287,8 +262,7 @@ static char *get_base(x)
     return cha_s_atom(cha_car(cha_cdr(y)));
 }
 
-static char *get_pron(x)
-    chasen_cell_t *x;
+static char *get_pron(chasen_cell_t *x)
 {
     chasen_cell_t *y;
     char *s;
@@ -308,8 +282,7 @@ static char *get_pron(x)
 /*
  * trim_midasi_gobi
  */
-static void trim_midasi_gobi(mrph)
-    mrph_t *mrph;
+static void trim_midasi_gobi(mrph_t *mrph)
 {
     char *gobi;
 
@@ -323,8 +296,7 @@ static void trim_midasi_gobi(mrph)
 /*
  * trim_yomi_gobi
  */
-static void trim_yomi_gobi(mrph)
-    mrph_t *mrph;
+static void trim_yomi_gobi(mrph_t *mrph)
 {
     char *gobi;
 
@@ -343,8 +315,7 @@ static void trim_yomi_gobi(mrph)
 /*
  * trim_pron_gobi
  */
-static void trim_pron_gobi(mrph)
-    mrph_t *mrph;
+static void trim_pron_gobi(mrph_t *mrph)
 {
     char *gobi;
 
@@ -363,14 +334,8 @@ static void trim_pron_gobi(mrph)
 /*
  * trans_mrph
  */
-static chasen_cell_t *get_mrph(block, mrph, def_weight, need_kform)
-    chasen_cell_t *block;
-    mrph_t *mrph;
-    int def_weight, need_kform;
+static chasen_cell_t *get_mrph(chasen_cell_t *block, mrph_t *mrph, int def_weight, int need_kform)
 {
-#ifdef KOCHA2
-    char *midasi_last;
-#endif
     int katuyou;
     char *s;
 
@@ -382,22 +347,8 @@ static chasen_cell_t *get_mrph(block, mrph, def_weight, need_kform)
       mrph->ktype = mrph->kform = 0;
     else {
 	mrph->ktype = cha_get_type_id(cha_s_atom(cha_car(cha_cdr(cha_car(block)))));
-/*
- *
- * FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! 
- *
- */
 	mrph->kform = cha_get_form_id(cha_s_atom(cha_car(cha_cdr(cha_cdr(cha_car(block))))),
 				  mrph->ktype);
-/*
-	mrph->kform = cha_get_form_id(cha_s_atom(cha_car(cha_cdr(cha_cdr(cha_car(block))))),
-				  mrph->ktype, need_kform);
-*/
-/*
- *
- * FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! FIX ME! 
- *
- */
     }
     block = cha_cdr(block);
 
@@ -439,27 +390,10 @@ static chasen_cell_t *get_mrph(block, mrph, def_weight, need_kform)
 #endif
     block = cha_cdr(block);
 
-#ifdef KOCHA2
-    if (*mrph->yomi == '\0') 
-      strcpy(mrph->yomi, mrph->midasi);
-    if (katuyou == 2) {
-	midasi_last = mrph->yomi + strlen(mrph->yomi) - 2;
-	if (is_moeum(midasi_last))
-	  mrph->ktype = cha_get_type_id("첻");
-	else if (!strcmp(midasi_last, ""))
-	  mrph->ktype = cha_get_type_id("");
-	else
-	  mrph->ktype = cha_get_type_id("Ҳ");
-    }
-#endif
-
     return block;
 }
 
-static void trans_mrph(block, def_weight, fp_out)
-    chasen_cell_t *block;
-    int def_weight;
-    FILE *fp_out;
+static void trans_mrph(chasen_cell_t *block, int def_weight, FILE *fp_out)
 {
     mrph_t *mrph, mrphs[256];
     chasen_cell_t *block0 = block;
@@ -488,10 +422,7 @@ static void trans_mrph(block, def_weight, fp_out)
 /*
  * trans_word
  */
-static void get_word(block, mrph, def_weight, need_kform, gets_midasi)
-    chasen_cell_t *block;
-    mrph_t *mrph;
-    int def_weight, need_kform, gets_midasi;
+static void get_word(chasen_cell_t *block, mrph_t *mrph, int def_weight, int need_kform, int gets_midasi)
 {
     int    katuyou, hinsi;
     chasen_cell_t *connect_cell; /* EDRdic '94.Mar */
@@ -507,7 +438,7 @@ static void get_word(block, mrph, def_weight, need_kform, gets_midasi)
     else {
 	mrph->ktype = get_ktype(block);
 	if (need_kform)
-	  mrph->kform = get_kform(block, mrph->ktype, need_kform);
+	  mrph->kform = get_kform(block, mrph->ktype);
 	else
 	  mrph->kform = 0;
     }
@@ -543,16 +474,9 @@ static void get_word(block, mrph, def_weight, need_kform, gets_midasi)
 #endif
 }
 
-static void trans_word(block, mrph0, def_weight, fp_out)
-    chasen_cell_t *block;
-    mrph_t *mrph0;
-    int def_weight;
-    FILE *fp_out;
+static void trans_word(chasen_cell_t *block, mrph_t *mrph0, int def_weight, FILE *fp_out)
 {
     chasen_cell_t *midasi_list;
-#ifdef KOCHA2
-    char   *midasi_last;
-#endif
     mrph_t *mrph, mrphs[256];
     int def_hinsi = mrph0->hinsi;
     int katuyou;
@@ -599,25 +523,11 @@ static void trans_word(block, mrph0, def_weight, fp_out)
 	if (katuyou == 1)
 	  trim_midasi_gobi(mrph);
 
-#ifdef KOCHA2
-	if (*mrph->yomi == '\0') 
-	  strcpy(mrph->yomi, mrph->midasi);
-	if (katuyou == 2) {
-	    midasi_last = mrph->yomi + strlen(mrph->yomi) - 2;
-	    if (is_moeum(midasi_last))
-		mrph->ktype = cha_get_type_id("첻");
-	    else if (!strcmp(midasi_last, ""))
-		mrph->ktype = cha_get_type_id("");
-	    else
-		mrph->ktype = cha_get_type_id("Ҳ");
-	}
-#endif
 	print_mrph(fp_out, mrph);
     }
 }
 
-void trans(fp_in, fp_out)
-    FILE *fp_in, *fp_out;
+void trans(FILE *fp_in, FILE *fp_out)
 {
     mrph_t mrphs[2], *mrph;
     chasen_cell_t *cell;
